import java.io.*;
import java.util.*;

/**
 * @author Roman V Satyukov
 */
public class bridge_rs implements Runnable {
	private static final double eps = 1e-8;
	private final String problemID = getClass().getName().split("_")[0].toLowerCase();
	private BufferedReader in;
	private PrintWriter out;
	
	private class Point {
		public int x, y;
		
		public Point(int x, int y) {
			this.x = x;
			this.y = y;
		}

		public Point(String str) {
			StringTokenizer st = new StringTokenizer(str);
			x = Integer.parseInt(st.nextToken());
			y = Integer.parseInt(st.nextToken());
			check(Math.abs(x) <= 10000, "Some x-coordinate is not in [-10000..10000]");
			check(Math.abs(y) <= 10000, "Some y-coordinate is not in [-10000..10000]");
		}

		public double distanceTo(Point p) {
			return Math.hypot(x - p.x, y - p.y);
		}
	}
	
	private void check(boolean expr, String message) {
		if (!expr) {
			throw new AssertionError(message);
		}
	}
	
	private void solve() throws IOException {
		int m = Integer.parseInt(in.readLine());
		check((1 <= m) && (m <= 100), "m is not in [1..100]");
		Point[] first = new Point[m + 2];
		for (int i = 0; i < m; i++) {
			first[i + 1] = new Point(in.readLine());
		}
		first[0] = new Point(first[1].x, -10010);
		first[m + 1] = new Point(first[m].x, 10010);
		
		int n = Integer.parseInt(in.readLine());
		check((1 <= n) && (n <= 100), "n is not in [1..100]");
		Point[] second = new Point[n + 2];
		for (int i = 0; i < n; i++) {
			second[i + 1] = new Point(in.readLine());
		}
		second[0] = new Point(second[1].x, -10010);
		second[n + 1] = new Point(second[n].x, 10010);
		
		check(first[1].x < second[1].x, "x_{1,1} >= x_{2,1}");
		for (int i = 0; i + 1 < first.length; i++) {
			for (int j = i + 2; j + 1 < first.length; j++) {
				check(!intersects(first[i], first[i + 1], first[j], first[j + 1]), "First line has self-intersections");
			}
		}
		for (int i = 0; i + 1 < second.length; i++) {
			for (int j = i + 2; j + 1 < second.length; j++) {
				check(!intersects(second[i], second[i + 1], second[j], second[j + 1]), "Second line has self-intersections");
			}
		}
		for (int i = 0; i + 1 < first.length; i++) {
			for (int j = 0; j + 1 < second.length; j++) {
				check(!intersects(first[i], first[i + 1], second[j], second[j + 1]), "First and second lines have intersections");
			}
		}
		
		double answer = Double.MAX_VALUE;
		for (int i = 0; i < first.length; i++) {
			for (int j = 0; j + 1 < second.length; j++) {
				double d = distance(first[i], second[j], second[j + 1]);
				answer = Math.min(answer, d);
			}
		}
		for (int i = 0; i + 1 < first.length; i++) {
			for (int j = 0; j < second.length; j++) {
				double d = distance(second[j], first[i], first[i + 1]);
				answer = Math.min(answer, d);
			}
		}
		out.println(answer);
	}
	
	private double distance(Point p, Point p1, Point p2) {
		double answer = Math.min(p.distanceTo(p1), p.distanceTo(p2));
		double a = (p2.y - p1.y);
		double b = (p1.x - p2.x);
		double c = -a * p1.x - b * p1.y;
		double d = Math.hypot(a, b);
		a /= d;
		b /= d;
		c /= d;
		double dist = a * p.x + b * p.y + c;
		double x = p.x - dist * a;
		double y = p.y - dist * b;
		if (bt(x, p1.x, p2.x) && bt(y, p1.y, p2.y)) {
			answer = Math.min(answer, Math.abs(dist));
		}
		return answer;
	}

	private boolean bt(double x, double u, double v) {
		return ((u - eps < x) && (x < v + eps)) || ((v - eps < x) && (x < u + eps));
	}

	private boolean intersects(Point p1, Point p2, Point p3, Point p4) {
		double x1 = Math.min(p1.x, p2.x);
		double x2 = Math.max(p1.x, p2.x);
		double y1 = Math.min(p1.y, p2.y);
		double y2 = Math.max(p1.y, p2.y);
		double x3 = Math.min(p3.x, p4.x);
		double x4 = Math.max(p3.x, p4.x);
		double y3 = Math.min(p3.y, p4.y);
		double y4 = Math.max(p3.y, p4.y);
		if (Math.max(x1, x3) > Math.min(x2, x4) + eps) {
			return false;
		}
		if (Math.max(y1, y3) > Math.min(y2, y4) + eps) {
			return false;
		}
		double s1 = area(p3, p4, p1) + area(p3, p4, p2);
		double s2 = area(p1, p2, p3) + area(p1, p2, p4);
		if (Math.abs(s1 - s2) > eps) {
			return false;
		}
		return true;
	}

	private double area(Point p1, Point p2, Point p3) {
		return Math.abs((p2.x - p1.x) * (p3.y - p1.y) - (p3.x - p1.x) * (p2.y - p1.y));
	}

	public static void main(String[] args) {
		new Thread(new bridge_rs()).start();
	}

	public void run() {
		try {
			in = new BufferedReader(new FileReader(new File(problemID + ".in")));
			out = new PrintWriter(new File(problemID + ".out"));
			solve();
			in.close();
			out.close();
		} catch (IOException e) {
			e.printStackTrace();
			System.exit(1);
		}
	}
}
