import java.io.*;
import java.util.*;

/**
 * @author Roman V Satyukov
 */
public class dfs_rs implements Runnable {
    private final String problemID = getClass().getName().split("_")[0].toLowerCase();
    private BufferedReader in;
    private PrintWriter out;
    private boolean[][] go, goNew;
    private boolean[] mark;
    private int[] t;
    private int currentPosition;
    
    private void check(boolean expr, String message) {
        if (!expr) {
            throw new AssertionError(message);
        }
    }
    
    private int processTree(int from, int to) {
        check(from <= to, "Invalid sequence of vertice (can't build a graph with this sequence)");
        if (from == to) {
            return t[from];
        }
        int first = t[from];
        int last = from;
        for (int i = from + 1; i <= to; i++) {
            if (t[i] == first) {
                int v = processTree(last + 1, i - 1);
                go[first][v] = go[v][first] = true;
                last = i;
            }
        }
        return first;
    }

    private void dfs(int u) {
        check(t[currentPosition++] == u, "Invalid sequence of vertice (can't build a graph with this sequence)");
        mark[u] = true;
        for (int v = 0; v < go.length; v++) {
            if (!go[u][v] && !mark[v]) {
                goNew[u][v] = goNew[v][u] = false;
            }
            if (!mark[v] && go[u][v]) {
                dfs(v);
                check(t[currentPosition++] == u, "Invalid sequence of vertice (can't build a graph with this sequence)");
            }
        }
    }

    private void solve() throws IOException {
        StringTokenizer st = new StringTokenizer(in.readLine());
        int n = Integer.parseInt(st.nextToken());
        int w = Integer.parseInt(st.nextToken());
        check((1 <= n) && (n <= 300), "n is not in [1..300]");
        check((1 <= w) && (w <= 2 * n - 1), "L is not in [1..2n-1]");
        t = new int[w];
        for (int i = 0; i < w; i++) {
            t[i] = Integer.parseInt(in.readLine()) - 1;
            check((0 <= t[i]) && (t[i] < n), "Some of vertice in sequence is not in [1..n]");
        }
        go = new boolean[n][n];
        for (int i = 0; i < w; ) {
            int last;
            for (last = w - 1; last >= i; last--) {
                if (t[last] == t[i]) {
                    break;
                }
            }
            processTree(i, last);
            i = last + 1;
        }
        mark = new boolean[n];
        currentPosition = 0;
        goNew = new boolean[n][n];
        for (int i = 0; i < n; i++) {
            for (int j = i + 1; j < n; j++) {
                goNew[i][j] = true;
            }
        }
        for (int i = 0; i < n; i++) {
            if (!mark[i]) {
                dfs(i);
            }
        }
        int count = 0;
        for (int i = 0; i < n; i++) {
            for (int j = i + 1; j < n; j++) {
                if (go[i][j] || goNew[i][j]) {
                    count++;
                }
            }
        }
        out.println(count);
        for (int i = 0; i < n; i++) {
            for (int j = i + 1; j < n; j++) {
                if (go[i][j] || goNew[i][j]) {
                    out.println((i + 1) + " " + (j + 1));
                }
            }
        }
    }
    
    public static void main(String[] args) {
        new Thread(new dfs_rs()).start();
    }

    public void run() {
        try {
            in = new BufferedReader(new FileReader(new File(problemID + ".in")));
            out = new PrintWriter(new File(problemID + ".out"));
            solve();
            in.close();
            out.close();
        } catch (IOException e) {
            e.printStackTrace();
            System.exit(1);
        }
    }
}
