import java.io.*;
import java.util.*;

/**
 * @author Roman V Satyukov
 */
public class optimize_rs_bug2 implements Runnable {
    private final String problemID = getClass().getName().split("_")[0].toLowerCase();
    private BufferedReader in;
    private PrintWriter out;
    
    private class Pair implements Comparable<Pair> {
        public int x, y;
        
        public Pair(int x, int y) {
            this.x = x;
            this.y = y;
        }

        public int compareTo(Pair that) {
            if (this.x != that.x) {
                return this.x - that.x;
            } else {
                return that.y - this.y;
            }
        }
    }

    private void check(boolean expr, String message) {
        if (!expr) {
            throw new AssertionError(message);
        }
    }
    
    private class SegmentsTree {
        private class Node {
            public int from, to;
            public Node left, right;
            public int value;
            
            public Node(int from, int to) {
                this.from = from;
                this.to = to;
                left = right = null;
            }
            
            public void add(int u, int value) {
                this.value += value;
                if (from == to) {
                    return;
                }
                int middle = (from + to >= 0) ? (from + to) / 2 : (from + to - 1) / 2;
                if (u <= middle) {
                    if (left == null) {
                        left = new Node(from, middle);
                    }
                    left.add(u, value);
                } else {
                    if (right == null) {
                        right = new Node(middle + 1, to);
                    }
                    right.add(u, value);
                }
            }
            
            public int calcSum(int u, int v) {
                if (v < from || u > to) {
                    return 0;
                }
                if (u <= from && to <= v) {
                    return value;
                }
                int answer = 0;
                if (left != null) {
                    answer += left.calcSum(u, v);
                }
                if (right != null) {
                    answer += right.calcSum(u, v);
                }
                return answer;
            }
        }
        
        private Node root;
        
        public SegmentsTree() {
            root = new Node(-1000000010, 1000000010);
        }
        
        public void add(int u, int value) {
            root.add(u, value);
        }
        
        public int calcSum(int u, int v) {
            return root.calcSum(u, v);
        }
    }
    
    private long calc(Pair[] p) {
        Arrays.sort(p);
        int n = p.length;
        long answer = 0;
        SegmentsTree st = new SegmentsTree();
        for (int i = 0; i < n; i++) {
            int cur = p[i].y - p[i].x;
            answer += st.calcSum(-1000000000, cur - 1);
            st.add(cur, 1);
        }
        return answer;
    }

    private void solve() throws IOException {
        StringTokenizer st = new StringTokenizer(in.readLine());
        int n = Integer.parseInt(st.nextToken());
        int m = Integer.parseInt(st.nextToken());
        check((1 <= n) && (n <= 100000), "n is not in [1..10^5]");
        check((1 <= m) && (m <= 100000), "m is not in [1..10^5]");
        st = new StringTokenizer(in.readLine());
        int[] w = new int[m];
        for (int i = 0; i < m; i++) {
            w[i] = Integer.parseInt(st.nextToken());
            check((1 <= w[i]) && (w[i] <= 1000000000), "Some of w[i] is not in [1..10^9]");
        }
        int[] p = new int[m];
        int[] sz = new int[n];
        Arrays.fill(p, -1);
        for (int i = 0; i < n; i++) {
            st = new StringTokenizer(in.readLine());
            int u = Integer.parseInt(st.nextToken());
            sz[i] = 0;
            for (int j = 0; j < u; j++) {
                int v = Integer.parseInt(st.nextToken());
                check((1 <= v) && (v <= m) && (p[v - 1] == -1), "Incorrect description");
                p[v - 1] = i;
                sz[i] += w[v - 1];
            }
        }
        for (int i = 0; i < m; i++) {
            check(p[i] != -1, "Not all parts are used");
        }
        Pair[] pairs = new Pair[m];
        for (int i = 0; i < m; i++) {
            pairs[i] = new Pair(w[i], sz[p[i]]);
        }
        out.println(calc(pairs));
    }

    public void run() {
        try {
            in = new BufferedReader(new FileReader(new File(problemID + ".in")));
            out = new PrintWriter(new File(problemID + ".out"));
            solve();
            in.close();
            out.close();
        } catch (IOException e) {
            e.printStackTrace();
            System.exit(1);
        }
    }
    
    public static void main(String[] args) {
        new Thread(new optimize_rs_bug2()).start();
    }
}
