import java.io.*;
import java.util.*;

/**
 * @author Roman V Satyukov
 */
public class optimize_rs_bug3 implements Runnable {
    private final String problemID = getClass().getName().split("_")[0].toLowerCase();
    private Random rnd;
    private BufferedReader in;
    private PrintWriter out;
    
    private class Pair implements Comparable<Pair> {
        public long x, y;
        
        public Pair(long x, long y) {
            this.x = x;
            this.y = y;
        }

        public int compareTo(Pair that) {
            if (this.x > that.x) {
                return 1;
            } else if (this.x < that.x) {
                return -1;
            } else {
                return 0;
            }
        }
    }

    private void check(boolean expr, String message) {
        if (!expr) {
            throw new AssertionError(message);
        }
    }
    
    private class CartesianTree {
        private int[] left;
        private int[] right;
        private long[] x;
        private int[] y, s, c;
        private int root, size;
        private int splitLeft, splitRight;
        
        private void updateSize(int cur) {
            s[cur] = c[cur];
            if (left[cur] != -1) {
                s[cur] += s[left[cur]];
            }
            if (right[cur] != -1) {
                s[cur] += s[right[cur]];
            }
        }

        private void split(int cur, long xValue) {
            if (cur == -1) {
                splitLeft = splitRight = -1;
                return;
            }
            if (xValue < x[cur]) {
                split(left[cur], xValue);
                left[cur] = splitRight;
                splitRight = cur;
            } else {
                split(right[cur], xValue);
                right[cur] = splitLeft;
                splitLeft = cur;
            }
            updateSize(cur);
        }

        private int add(int cur, long xValue, int yValue) {
            if (cur == -1 || yValue > y[cur]) {
                split(cur, xValue);
                x[size] = xValue;
                y[size] = yValue;
                c[size] = 1;
                left[size] = splitLeft;
                right[size] = splitRight;
                updateSize(size);
                size++;
                return size - 1;
            }
            if (xValue < x[cur]) {
                left[cur] = add(left[cur], xValue, yValue);
            } else {
                right[cur] = add(right[cur], xValue, yValue);
            }
            updateSize(cur);
            return cur;
        }
        
        private boolean find(int cur, long xValue) {
            if (cur == -1) {
                return false;
            }
            if (xValue == x[cur]) {
                c[cur]++;
                s[cur]++;
                return true;
            }
            boolean result;
            if (xValue < x[cur]) {
                result = find(left[cur], xValue);
            } else {
                result = find(right[cur], xValue);
            }
            if (result) {
                updateSize(cur);
            }
            return result;
        }
        
        private long calcLess(int cur, long xValue) {
            if (cur == -1) {
                return 0;
            }
            if (xValue <= x[cur]) {
                return calcLess(left[cur], xValue);
            } else {
                long answer = c[cur];
                if (left[cur] != -1) {
                    answer += s[left[cur]];
                }
                answer += calcLess(right[cur], xValue);
                return answer;
            }
        }

        public CartesianTree(int n) {
            left = new int[n];
            right = new int[n];
            x = new long[n];
            y = new int[n];
            s = new int[n];
            c = new int[n];
            root = -1;
            size = 0;
        }

        public long calcLess(long value) {
            return calcLess(root, value);
        }

        public void add(long value) {
            if (find(root, value)) {
                return;
            }
            root = add(root, value, rnd.nextInt());
        }
        
        public void print() {
            print(root);
            System.out.println();
        }

        private void print(int cur) {
            if (cur == -1) {
                return;
            }
            print(left[cur]);
            if (c[cur] != 1) {
                System.out.print(x[cur] + "[" + c[cur] + "] ");
            } else {
                System.out.print(x[cur] + " ");
            }
            print(right[cur]);
        }
    }
    
    private long calc(Pair[] p) {
        Arrays.sort(p);
        int n = p.length;
        long answer = 0;
        CartesianTree tree = new CartesianTree(n);
        for (int i = 0; i < n; i++) {
//          tree.print();
//          
            long cur = p[i].y - p[i].x;
            answer += tree.calcLess(cur);
            tree.add(cur);
        }
        return answer;
    }

    private void solve() throws IOException {
        StringTokenizer st = new StringTokenizer(in.readLine());
        int n = Integer.parseInt(st.nextToken());
        int m = Integer.parseInt(st.nextToken());
        check((1 <= n) && (n <= 100000), "n is not in [1..10^5]");
        check((1 <= m) && (m <= 100000), "m is not in [1..10^5]");
        st = new StringTokenizer(in.readLine());
        int[] w = new int[m];
        for (int i = 0; i < m; i++) {
            w[i] = Integer.parseInt(st.nextToken());
            check((1 <= w[i]) && (w[i] <= 1000000000), "Some of w[i] is not in [1..10^9]");
        }
        int[] p = new int[m];
        long[] sz = new long[n];
        Arrays.fill(p, -1);
        rnd = new Random(25252524);
        for (int i = 0; i < n; i++) {
            st = new StringTokenizer(in.readLine());
            int u = Integer.parseInt(st.nextToken());
            sz[i] = 0;
            for (int j = 0; j < u; j++) {
                int v = Integer.parseInt(st.nextToken());
                check((1 <= v) && (v <= m) && (p[v - 1] == -1), "Incorrect description");
                p[v - 1] = i;
                sz[i] += w[v - 1];
            }
        }
        for (int i = 0; i < m; i++) {
            check(p[i] != -1, "Not all parts are used");
        }
        Pair[] pairs = new Pair[m];
        for (int i = 0; i < m; i++) {
            pairs[i] = new Pair(w[i], sz[p[i]]);
        }
        out.println(calc(pairs));
    }

    public void run() {
        try {
            in = new BufferedReader(new FileReader(new File(problemID + ".in")));
            out = new PrintWriter(new File(problemID + ".out"));
            solve();
            in.close();
            out.close();
        } catch (IOException e) {
            e.printStackTrace();
            System.exit(1);
        }
    }
    
    public static void main(String[] args) {
        new Thread(new optimize_rs_bug3()).start();
    }
}
