import java.io.*;
import java.util.*;

/**
 * @author Roman V Satyukov
 */
public class spiral_rs implements Runnable {
	private final String problemID = getClass().getName().split("_")[0].toLowerCase();
	private BufferedReader in;
	private PrintWriter out;
	
	private void check(boolean expr, String message) {
		if (!expr) {
			throw new AssertionError(message);
		}
	}
	
	// Find max f(t) = (a + t) * cos(t) with t from [tMin..tMax]
	private double findMax(double a, double tMin, double tMax) {
		if (tMax > 4 * Math.PI + tMin) {
			return Math.max(findMax(a, tMin, tMin + 2 * Math.PI), findMax(a, tMax - 2 * Math.PI, tMax));
		}
		if (tMax < tMin + 1e-9) {
			return (a + tMin) * Math.cos(tMin);
		}
		
		double dt = (tMax - tMin) / 10000;
		double answer = -Double.MAX_VALUE;
		double maxt = 0.0;
		for (int step = 0; step <= 10000; step++) {
			double t = tMin + step * dt;
			double f = (a + t) * Math.cos(t);
			if (f > answer) {
				answer = f;
				maxt = t;
			}
		}
		double left = Math.max(tMin, maxt - dt * 10);
		double right = Math.min(tMax, maxt + dt * 10);
		return findMax(a, left, right);
	}
	
	// Find min f(t) = (a + t) * cos(t) with t from [tMin..tMax]
	private double findMin(double a, double tMin, double tMax) {
		return -findMax(-a, -tMax, -tMin);
	}
	
	// Find max f(t) = (a + bt)cos(wt) with t from [0..tMax]
	// a, b, w > 0
	private double findMaxCos(double a, double b, double w, double tMax) {
		return findMax(a * w / b, 0, w * tMax) * b / w;
	}
	
	// Find min f(t) = (a + bt)cos(wt) with t from [0..tMax]
	// a, b, w > 0
	private double findMinCos(double a, double b, double w, double tMax) {
		return findMin(a * w / b, 0, w * tMax) * b / w;
	}
	
	// Find max f(t) = (a + bt)sin(wt) with t from [0..tMax]
	// a, b, w > 0
	private double findMaxSin(double a, double b, double w, double tMax) {
		double u = a + b * Math.PI / w / 2.0;
		double v = b / w;
		return findMax(u / v, -Math.PI / 2, w * tMax - Math.PI / 2) * v;
	}
	
	// Find min f(t) = (a + bt)sin(wt) with t from [0..tMax]
	// a, b, w > 0
	private double findMinSin(double a, double b, double w, double tMax) {
		double u = a + b * Math.PI / w / 2.0;
		double v = b / w;
		return findMin(u / v, -Math.PI / 2, w * tMax - Math.PI / 2) * v;
	}
	
	private void solve() throws IOException {
		StringTokenizer st = new StringTokenizer(in.readLine());
		int W = Integer.parseInt(st.nextToken());
		int V = Integer.parseInt(st.nextToken());
		int R = Integer.parseInt(st.nextToken());
		int T = Integer.parseInt(st.nextToken());
		check((1 <= W) && (W <= 100), "W is not in [1..100]");
		check((1 <= V) && (V <= 100), "V is not in [1..100]");
		check((0 <= R) && (R <= 100), "R is not in [0..100]");
		check((1 <= T) && (T <= 100000), "T is not in [1..100000]");
		double w = Math.PI * W / 180.0;
		
		double xMax = findMaxCos(R, V, w, T);
		double xMin = findMinCos(R, V, w, T);
		double yMax = findMaxSin(R, V, w, T);
		double yMin = findMinSin(R, V, w, T);
		out.println(xMin + " " + yMin);
		out.println(xMax + " " + yMax);
	}
	
	public static void main(String[] args) {
		new Thread(new spiral_rs()).start();
	}

	public void run() {
		try {
			in = new BufferedReader(new FileReader(new File(problemID + ".in")));
			out = new PrintWriter(new File(problemID + ".out"));
			solve();
			in.close();
			out.close();
		} catch (IOException e) {
			e.printStackTrace();
			System.exit(1);
		}
	}
}
