#define _USE_MATH_DEFINES

#include <cstdio>
#include <cmath>
#include <cassert>

#define forn(i, n) for (int i = 0; i < (int)(n); i++)

#define inf 1e20
#define cot(t) (1.0 / tan(t))

typedef double dbl;

dbl w, maxt, k, r;
dbl rx1 = inf, ry1 = inf, rx2 = -inf, ry2 = -inf;

void Relax( dbl t )
{
  if (t < 0 || t > maxt + 1e-9)
    return;
  
  dbl x = (k * t + r) * cos(t);
  dbl y = (k * t + r) * sin(t);

//  fprintf(stderr, "t=%.5lf [x=%.5lf y=%.5lf x'=%.5lf y'=%.5lf]\n", t, x, y,
//    k * cos(t) - (k * t + r) * sin(t), k * sin(t) + (k * t + r) * cos(t));

  if (x < rx1) rx1 = x;
  if (x > rx2) rx2 = x;
  if (y < ry1) ry1 = y;
  if (y > ry2) ry2 = y;
}

dbl Solve1( dbl t )
{
  dbl mi = t, ma = t + M_PI;
  forn(j, 50)
  {
    t = (mi + ma) * 0.5;
    if (cot(t) > t + r / k)
      mi = t;
    else
      ma = t;
  }
  return mi;
}

dbl Solve2( dbl t )
{
  dbl mi = t - M_PI / 2, ma = t + M_PI / 2;
  forn(j, 50)
  {
    t = (mi + ma) * 0.5;
    if (-tan(t) > t + r / k)
      mi = t;
    else
      ma = t;
  }
  return mi;
}

int main()
{
  freopen("spiral.in", "r", stdin);
  freopen("spiral.out", "w", stdout);

  int W, V, R, T;
  assert(scanf("%d%d%d%d", &W, &V, &R, &T) == 4);
  assert(1 <= W && W <= 100);
  assert(1 <= V && V <= 100);
  assert(0 <= R && R <= 100);
  assert(1 <= T && T <= 1000);

  w = W * M_PI / 180;
  maxt = T * w;
  k = V / w;
  r = R;

  Relax(0);
  Relax(maxt);

  for (dbl a = 2 * M_PI * ((int)(maxt / (2 * M_PI)) - 1); a < maxt + M_PI; a += M_PI)
  {                    
    Relax(Solve1(a));
    Relax(Solve2(a));
  }

  printf("%.20lf %.20lf\n%.20lf %.20lf\n", rx1, ry1, rx2, ry2);
  return 0;
}
