import java.io.*;

/**
 * @author Roman V Satyukov
 */
public class sum_rs implements Runnable {
	private final String problemID = getClass().getName().split("_")[0].toLowerCase();
	private BufferedReader in;
	private PrintWriter out;
	
	private void check(boolean expr, String message) {
		if (!expr) {
			throw new AssertionError(message);
		}
	}
	
	private void checkNumber(String a, String str) {
		check((1 <= a.length()) && (a.length() <= 100001), "Length of " + str + " is not in [1..100001]");
		int ones = 0;
		int zeroes = 0;
		for (int i = 0; i < a.length(); i++) {
			char ch = a.charAt(i);
			if (ch == '0') {
				zeroes++;
			} else if (ch == '1') {
				ones++;
			}
			check(('0' <= ch) && (ch <= '9'), str + " is not a number");
		}
		check(a.charAt(0) != '0', "Leading zeros in " + str);
		if (a.length() == 100001) {
			check(ones == 1 && zeroes == 100000, "Number " + str + " is too big");
		}
	}
	
	private int getNumberOfZeroes(String a) {
		int z = a.length() - 1;
		while (a.charAt(z) == '0') {
			z--;
		}
		return a.length() - z - 1;
	}
	
	private int compare(int n, int[] a, int m, int[] b) {
		if (n > m) {
			return 1;
		} else if (n < m) {
			return -1;
		}
		for (int i = n - 1; i >= 0; i--) {
			if (a[i] > b[i]) {
				return 1;
			} else if (a[i] < b[i]) {
				return -1;
			}
		}
		return 0;
	}
	
	private int sum(int n, int[] a, int m, int[] b, int[] c) {
		int size = Math.max(n, m) + 1;
		int s = 0;
		for (int i = 0; i < size; i++) {
			int t = s;
			if (i < a.length) {
				t += a[i];
			}
			if (i < b.length) {
				t += b[i];
			}
			c[i] = t % 10;
			s = t / 10;
		}
		while (size > 0 && c[size - 1] == 0) {
			size--;
		}
		return size;
	}
	
	private int sub(int n, int[] a, int m, int[] b, int[] c) {
		int s = 0;
		for (int i = 0; i < n; i++) {
			int t = s;
			if (i < a.length) {
				t += a[i];
			}
			if (i < b.length) {
				t -= b[i];
			}
			if (t < 0) {
				t += 10;
				s = -1;
			} else {
				s = 0;
			}
			c[i] = t;
		}
		while (n > 0 && c[n - 1] == 0) {
			n--;
		}
		return n;
	}
	
	private int equals(int n, int[] a, int m, int[] b) {
		if (n > m) {
			return -1;
		}
		int offset = m - n;
		for (int i = 0; i < n; i++) {
			if (a[i] != b[i + offset]) {
				return -1;
			}
		}
		return offset;
	}
	
	private int[] getIntArray(String a) {
		int n = a.length();
		int[] result = new int[n];
		for (int i = 0; i < n; i++) {
			result[i] = a.charAt(n - i - 1) - '0';
		}
		return result;
	}

	private void solve() throws IOException {
		String a = in.readLine();
		String b = in.readLine();
		String c = in.readLine();
		checkNumber(a, "A");
		checkNumber(b, "B");
		checkNumber(c, "C");
		int za = getNumberOfZeroes(a);
		int zb = getNumberOfZeroes(b);
		int zc = getNumberOfZeroes(c);
		a = a.substring(0, a.length() - za);
		b = b.substring(0, b.length() - zb);
		c = c.substring(0, c.length() - zc);
		
		int[] aa = getIntArray(a);
		int[] bb = getIntArray(b);
		int[] cc = getIntArray(c);
		int[] tmp = new int[Math.max(Math.max(aa.length, bb.length), cc.length) + 1];
		
		/* k != 0 */
		int tmpSize = sum(aa.length, aa, bb.length, bb, tmp);
		int offset = equals(cc.length, cc, tmpSize, tmp);
		if (offset != -1) {
			printAnswer(za, zb, zc, 0, 0, offset);
			return;
		}
		
		/* n != 0 */
		if (compare(cc.length, cc, bb.length, bb) > 0) {
			tmpSize = sub(cc.length, cc, bb.length, bb, tmp);
			offset = equals(aa.length, aa, tmpSize, tmp);
			if (offset != -1) {
				printAnswer(za, zb, zc, offset, 0, 0);
				return;
			}
		}
		
		/* m != 0 */
		if (compare(cc.length, cc, aa.length, aa) > 0) {
			tmpSize = sub(cc.length, cc, aa.length, aa, tmp);
			offset = equals(bb.length, bb, tmpSize, tmp);
			if (offset != -1) {
				printAnswer(za, zb, zc, 0, offset, 0);
				return;
			}
		}
		out.println("NO");
	}
	
	private void printAnswer(int za, int zb, int zc, int n, int m, int k) {
		n = n - za;
		m = m - zb;
		k = k - zc;
		int min = Math.min(Math.min(n, m), k);
		n = n - min;
		m = m - min;
		k = k - min;
		out.println("YES");
		out.println(n + " " + m + " " + k);
	}

	public static void main(String[] args) {
		new Thread(new sum_rs()).start();
	}

	public void run() {
		try {
			in = new BufferedReader(new FileReader(new File(problemID + ".in")));
			out = new PrintWriter(new File(problemID + ".out"));
			solve();
			in.close();
			out.close();
		} catch (IOException e) {
			e.printStackTrace();
			System.exit(1);
		}
	}
}
