#define NDEBUG

#include <algorithm>
#include <cassert>
#include <cstdio>
#include <cstring>

using namespace std;

const int MAXN = 200000;
const int MAXM = 200000;

struct Node {
	bool dead;
	int id;
	int median;
	int left;
	int right;
};

int n, m;
int start[MAXM], finish[MAXM];
int mate[MAXN + 10];
int ind[MAXM];
Node nodes[MAXM];
int id2node[MAXM], nnodes = 0;
int todel[MAXM], ntodel;
bool was[MAXN + 10];

bool cmp(int p, int q) {
	return start[p] < start[q];
}

int build(int l, int r) {
	int root = -1;
	for (int i = l; i <= r; i++) {
		if (id2node[ind[i]] != -1) continue;
		if (root == -1 || finish[ind[i]] < finish[root]) root = ind[i];
	}
	if (root == -1) return -1;
	int cur = nnodes++;
	nodes[cur].dead = false;
	id2node[root] = cur;
	nodes[cur].id = root;
	int m = (l + r) / 2;
	nodes[cur].median = start[ind[m]];
	nodes[cur].left = build(l, m);
	nodes[cur].right = build(m + 1, r);
	return cur;
}

bool isbad(int node) {
	return node == -1 || nodes[node].dead;
}

void query(int node, int x0, int y0) {
	if (isbad(node)) return;
	if (finish[nodes[node].id] > y0) return;
	if (start[nodes[node].id] >= x0) {
		todel[ntodel++] = nodes[node].id;
	}
	query(nodes[node].right, x0, y0);
	if (nodes[node].median >= x0) query(nodes[node].left, x0, y0);
}

void treedel(int node) {
	assert(!isbad(node));
	if (isbad(nodes[node].left) && isbad(nodes[node].right)) {
		nodes[node].dead = true;
		return;
	}
	int best = -1;
	if (!isbad(nodes[node].left) && (best == -1 || finish[nodes[nodes[node].left].id] < finish[nodes[best].id]))
		best = nodes[node].left;
	if (!isbad(nodes[node].right) && (best == -1 || finish[nodes[nodes[node].right].id] < finish[nodes[best].id]))
		best = nodes[node].right;
	assert(!isbad(best));
	swap(nodes[node].id, nodes[best].id);
	id2node[nodes[node].id] = node;
	id2node[nodes[best].id] = best;
	treedel(best);
}

void self_check(int node, int y0, int x1, int x2) {
	if (node == -1) return;
	if (nodes[node].dead) {
		assert(isbad(nodes[node].left));
		assert(isbad(nodes[node].right));
		return;
	}
	assert(finish[nodes[node].id] >= y0);
	assert(start[nodes[node].id] >= x1);
	assert(start[nodes[node].id] <= x2);
	self_check(nodes[node].left, finish[nodes[node].id], x1, nodes[node].median);
	self_check(nodes[node].right, finish[nodes[node].id], nodes[node].median, x2);
}

int main() {
	if (scanf("%d", &n) != 1) assert(false);
	assert(n >= 1);
	assert(n <= MAXN);
	if (scanf("%d", &m) != 1) assert(false);
	assert(m >= 1);
	assert(m <= MAXM);
	for (int i = 0; i < m; i++) {
		if (scanf("%d%d", &start[i], &finish[i]) != 2) assert(false);
		assert(1 <= start[i]);
		assert(start[i] <= finish[i]);
		assert(finish[i] <= n);
	}
	memset(mate, 255, sizeof(mate));
	for (int i = 0; i < m; i++) {
		ind[i] = i;
	}
	sort(ind, ind + m, cmp);
	memset(id2node, 255, sizeof(id2node));
	int root = build(0, m - 1);
	assert(nnodes == m);
	int ans = 0;
	memset(was, 0, sizeof(was));
	for (int i = 0; i < n; i++) {
		int k;
		scanf("%d", &k);
		assert(!was[k]);
		was[k] = true;
		int least = k, most = k;
		if (mate[k - 1] != -1) least = mate[k - 1];
		if (mate[k + 1] != -1) most = mate[k + 1];
		mate[least] = most;
		mate[most] = least;
		ntodel = 0;
		query(root, least, most);
		for (int j = 0; j < ntodel; j++) {
			treedel(id2node[todel[j]]);
			ans++;
		}
		printf("%d\n", ans);
		fflush(stdout);
	}
	return 0;
}
