#define _CRT_SECURE_NO_WARNINGS

#include <string>
#include <vector>
#include <cmath>
#include <map>
#include <algorithm>
#include <queue>
#include <set>
#include <iostream>
#include <sstream>
#include <cstdio>
#include <cassert>
#include <utility>

using namespace std;

#define INF (int)(1e+9)

#define forn(i, n) for (int i = 0; i < int(n); i++)
#define forv(i, a) for (int i = 0; i < int(a.size()); i++)
#define fors(i, a) for (int i = 0; i < int(a.length()); i++)
#define all(a) a.begin(), a.end()
#define pb push_back
#define mp make_pair
#define VI vector<int>
#define VS vector<string>

#define norm(a) sort(all(a)); a.erase(unique(all(a)), a.end());
#define num(a, v) (int)(lower_bound(all(a), v) - a.begin())

#define C_IN_FILE "input.txt"
#define C_OUT_FILE "output.txt"

const int MAXN = 100000;
const int MAXM = 500000;
const long long MOD = 1000000007;
const long long div2 = (MOD + 1) / 2;

int n, m, t;
vector<int> g[MAXN];
bool tv[MAXN];

struct dist {
    int d;
    int kv;
    int vs[2];
    long long kpath;

    dist(): d(INF), kv(0), kpath(0) {
    }

    dist(int d, int v): d(d), kv(1), kpath(1) {
        vs[0] = v;
    }

    bool update(int nd, int v, long long nkpath) {
        if (nd > d) {
            return false;
        }
        if (nd == d) {
            if (kv < 2) {
                vs[kv++] = v;
            }
            kpath = (kpath + nkpath) % MOD;
            return false;
        } else {
            d = nd;
            vs[0] = v;
            kv = 1;
            kpath = nkpath;
            return true;
        }
    }

    dist inc(int b = 1) {
        dist res = *this;
        res.d += b;
        return res;
    }

    bool update(const dist& nd) {
        bool res = false;
        forn(i, nd.kv) {
            if (update(nd.d, nd.vs[i], nd.kpath)) {
                res = true;
            }
        }
        return res;
    }

    int sum(const dist& nd) {
        int res = INF;
        forn(i, kv) {
            forn(j, nd.kv) {
                if (vs[i] != nd.vs[j]) {
                    res = d + nd.d;
                }
            }
        }
        return res;
    }

    int gran_vertex() {
        if (kv == 1) {
            return vs[0];
        } else {
            return -1;
        }
    }
};

dist d[MAXN];
queue<int> q;

int dst_res;
long long kpath_res;

void outdata() {
    cout << dst_res << " " << kpath_res << endl;
}

void solve() {
    forn(i, n) if (tv[i]) {
        d[i] = dist(0, i);
        q.push(i);
    }
    while (!q.empty()) {
        int v = q.front();
        q.pop();
        dist ndist = d[v].inc();
        forv(i, g[v]) {
            int u = g[v][i];
            if (d[u].update(ndist)) {
                q.push(u);
            }
        }
    }
    forn(i, n) assert(d[i].d != INF);
    dst_res = INF;
    forn(i, n) {
        forv(j, g[i]) {
            dst_res = min(dst_res, 1 + d[i].sum(d[g[i][j]]));
        }
    }

    kpath_res = 0;
    forn(i, n) {
        forv(j, g[i]) {
            int u = i, v = g[i][j];
			if (u > v) continue;
            int gu = d[u].gran_vertex(), gv = d[v].gran_vertex();
            if (gu != -1 &&  gv != -1 && gu != gv &&
                d[u].d + d[v].d + 1 == dst_res) {
                kpath_res = (kpath_res + d[u].kpath * d[v].kpath) % MOD;
            }
        }
    }
    forn(i, n) {
        int u = i;
        if (d[u].gran_vertex() != -1) continue;
        vector<long long> ks;
        forv(j, g[i]) {
            int v = g[i][j];
            if (d[v].gran_vertex() == -1) continue;
			if ((d[v].d + 1) * 2 == dst_res) {
                ks.pb(d[v].kpath);
            }
        }
        long long inc = 0;
        forv(j, ks) inc = (inc + ks[j]) % MOD;
        inc = (inc * inc) % MOD;
        forv(j, ks) inc = ((inc - ks[j] * ks[j]) % MOD + MOD) % MOD;
		inc = (inc * div2) % MOD;
        kpath_res = (kpath_res + inc) % MOD;
    }
}

void readdata() {
    scanf("%d%d%d", &n, &m, &t);
    assert(2 <= n && n <= MAXN);
    assert(1 <= m && m <= MAXM);
    assert(2 <= t && t <= n);
    memset(tv, 0, sizeof tv);
    forn(i, t) {
        int v;
        scanf("%d", &v);
        assert(1 <= v && v <= n);
        --v;
        assert(!tv[v]);
        tv[v] = true;
    }
    forn(i, m) {
        int u, v;
        scanf("%d%d", &u, &v);
        assert(u != v);
        assert(1 <= u && u <= n);
        assert(1 <= v && v <= n);
        --u; --v;
        g[u].pb(v);
        g[v].pb(u);
    }
    forn(i, n) {
        size_t t = g[i].size();
        norm(g[i]);
        assert(t == g[i].size());
    }
}

int main() {
	readdata();
	solve();
	outdata();
	return 0;
}
