#include <iostream>
#include <fstream>
#include <cstdio>
#include <cstring>
#include <set>
#include <cassert>
using namespace std;

#define ASSERTS

const int MAXN = 100000;
const int MAXM = 500000;
const int MAXC = 1000000000;

class Edge
{
public:
	int be, en;
	int c;
};

int n, m1, m2;
Edge edg[MAXM];
int first[MAXN + 1];
int rfirst[MAXN + 1];
int next[MAXM];
int rnext[MAXM];
int nume;

void AddEdge(int v1, int v2, int c, int f = 1)
{
	edg[nume].be = v1;
	edg[nume].en = v2;
	edg[nume].c = c;
	if (f == 1)
	{
		next[nume] = first[v1];
		first[v1] = nume;
		rnext[nume] = rfirst[v2];
		rfirst[v2] = nume;
	}
	nume++;
}

void Load()
{
	memset(first, 0xFF, sizeof(first));
	memset(rfirst, 0xFF, sizeof(rfirst));
	nume = 0;
	scanf("%d%d", &n, &m1);
	#ifdef ASSERTS
	assert(0 < n && n <= MAXN);
	#endif
	int i, p, q, c;
	for (i = 0; i < m1; i++)
	{
		scanf("%d%d", &p, &q);
		#ifdef ASSERTS
		assert(1 <= p && p <= n);
		assert(1 <= q && q <= n);
		#endif
		AddEdge(p, q, 0);
	}
	scanf("%d", &m2);

	for (i = 0; i < m2; i++)
	{
		scanf("%d%d%d", &p, &q, &c);
		#ifdef ASSERTS
		assert(1 <= p && p <= n);
		assert(1 <= q && q <= n);
		assert(-MAXC <= c && c <= MAXC);
		#endif
		if (c > 0) AddEdge(p, q, c, 0);
		else AddEdge(p, q, c);
	}
}

int ind[MAXN + 1];
int ctop;
int was[MAXN + 1];

void DfsTop(int ver)
{
	was[ver] = 1;
	int i;
	for (i = first[ver]; i != -1; i = next[i])
	{
		if (was[edg[i].en] != 0) continue;
		DfsTop(edg[i].en);
	}
	ind[ctop++] = ver;
}

int nc[MAXN + 1];
int ccom;

void DfsCom(int ver)
{
	nc[ver] = ccom;
	int i;
	for (i = rfirst[ver]; i != -1; i = rnext[i])
	{
		if (nc[edg[i].be] == 0)
		{
			DfsCom(edg[i].be);
		}
	}
}

int nout[MAXN + 1];
int nin[MAXN + 1];
long long dst[MAXN + 1];
int prev[MAXN + 1];
int bye[MAXN + 1];
int take[MAXM + 1];

class Vertex
{
public:
	int v;
};

bool operator<(const Vertex &a, const Vertex &b)
{
	if (dst[a.v] < dst[b.v]) return true;
	if (dst[a.v] > dst[b.v]) return false;
	if (a.v < b.v) return true;
	return false;
}

void Solve()
{
	memset(was, 0, sizeof(was));
	memset(take, 0, sizeof(take));
	int i;
	ctop = 0;
	for (i = 1; i <= n; i++)
	{
		if (was[i] == 0) 
		{
			DfsTop(i);
		}
	}
	memset(nc, 0, sizeof(nc));
	ccom = 0;
	for (i = ctop - 1; i >= 0; i--)
	{
		if (nc[ind[i]] == 0)
		{
			ccom++;
			DfsCom(ind[i]);
		}
	}
	memset(nin, 0, sizeof(nin));
	memset(nout, 0, sizeof(nout));
	for (i = 0; i < nume; i++)
	{
		if (edg[i].c <= 0)
		{
			if (nc[edg[i].be] != nc[edg[i].en])
			{
				nout[nc[edg[i].be]]++;
				nin[nc[edg[i].en]]++;
			}
		}
	}
	int numsrc, numsink;
	numsrc = numsink = 0;
	for (i = 1; i <= ccom; i++)
	{
		if (nin[i] == 0) numsrc++;
		if (nout[i] == 0) numsink++;
	}
	#ifdef ASSERTS
	assert(numsrc == 1);
	assert(numsink == 1);
	#endif
	int bver, ever;
	bver = ever = 0;
	for (i = 1; i <= n; i++)
	{
		if (nin[nc[i]] == 0) ever = i;
		if (nout[nc[i]] == 0) bver = i;
	}
	memset(first, 0xFF, sizeof(first));
	long long ans = 0;
	for (i = 0; i < nume; i++)
	{
		if (i >= m1 && edg[i].c <= 0) 
		{
			ans += edg[i].c;
			take[i] = 1;
			edg[i].c = 0;
		}
		next[i] = first[edg[i].be];
		first[edg[i].be] = i;
	}
	memset(dst, 0x7F, sizeof(dst));
	dst[bver] = 0;
	set<Vertex> v;
	Vertex a, b;
	a.v = bver;
	v.insert(a);
	while (v.size() > 0)
	{
		a = *v.begin();
		v.erase(v.begin());
		for (i = first[a.v]; i != -1; i = next[i])
		{
			if (dst[edg[i].en] > dst[a.v] + edg[i].c)
			{
				b.v = edg[i].en;
				v.erase(b);
				dst[b.v] = dst[a.v] + edg[i].c;
				prev[b.v] = a.v;
				bye[b.v] = i;
				v.insert(b);
			}
		}
	}
	if (dst[ever] == 0x7F7F7F7F7F7F7F7Fll)
	{
		printf("NO\n");
	}
	else
	{
		printf("YES\n");
		for (i = ever; i != bver; i = prev[i])
		{
			if (bye[i] >= m1)
			{
				take[bye[i]] = 1;
				ans += edg[bye[i]].c;
			}
		}
		cout << ans << "\n";
		int ntake = 0;
		for (i = m1; i < m1 + m2; i++)
		{
			if (take[i] == 1)
			{
				ntake++;
			}
		}
		printf("%d\n", ntake);
		for (i = m1; i < m1 + m2; i++)
		{
			if (take[i] == 1)
			{
				printf("%d\n", i - m1 + 1);
			}
		}
	}
}

int main()
{
//	freopen("aug.in", "rt", stdin);
	Load();
	Solve();
	return 0;
}
