#include <algorithm>
#include <cassert>
#include <cmath>
#include <cstdio>
#include <cstdlib>
#include <cstring>
#include <string>
#include <utility>
#include <vector>

#define TASKNAME "triangles"

using namespace std;

const int MinN = 1, MaxN = 21, MinK = 0, MaxK = 1000000000, MaxL = 1 << MaxN;
const int Prime = 262139, MaxH = 1 << 18, AndH = MaxH - 1;
const char NA = 'Z';

int f [MaxN + 1] [MaxH];
int h [MaxN + 1] [MaxH];
vector <pair <int, int> > g [MaxN] [MaxN + 1];
char ans [MaxN] [MaxN + 1];
int n;

inline void add (int * f, int * h, int index, int value)
{
 int cur;
 cur = (index * Prime) & AndH;
 while (h[cur] != index && h[cur] != -1)
  cur = (cur + 1) & AndH;
 if (h[cur] == -1)
 {
  h[cur] = index;
  f[cur] = value;
 }
 else
  f[cur] += value;
}

void out (void)
{
 int i, j;
 for (i = 0; i < n; i++)
 {
  for (j = 0; j < n - i - 1; j++)
   putchar (' ');
  for (j = n - i - 1; j < n; j++)
  {
   putchar (ans[i][j]);
   if (j + 1 == n)
    putchar ('\n');
   else
    putchar (' ');
  }
 }
 fflush (stdout);
}

int main (void)
{
 int i, j, k, l, m, r, t, z;
 vector <pair <int, int> >::iterator x;
 freopen (TASKNAME ".in", "rt", stdin);
 freopen (TASKNAME ".out", "wt", stdout);
 while (scanf (" %d %d", &n, &z) != EOF)
 {
  assert (MinN <= n && n <= MaxN);
  assert (MinK <= z && z <= MaxK);
  m = 1 << n;
  memset (h, -1, sizeof (h));
  memset (f, 0, sizeof (f));
  add (f[n], h[n], 0, 1);
  for (i = n - 1; i >= 0; i--)
  {
   printf ("i = %d\n", i);
   g[i][n].clear ();
   for (k = 0; k < MaxH; k++)
    if (h[n][k] != -1)
    {
     g[i][n].push_back (make_pair (h[n][k], f[n][k]));
     printf ("%d %d: %d %d\n", i, n, h[n][k], f[n][k]);
     fflush (stdout);
    }
   memset (h[n - 1], -1, sizeof (h[n - 1]));
   for (j = n - 1; j >= n - 1 - i; j--)
   {
    if (j > 0)
     memset (h[j - 1], -1, sizeof (h[j - 1]));
    for (k = 0; k < MaxH; k++)
     if (h[j + 1][k] != -1)
     {
      r = h[j + 1][k];
      t = f[j + 1][k];
      if (r & (1 << j))
      {
       add (f[j], h[j], r ^ (1 << j), t);
      }
      else
      {
       if (j - 1 >= 0 && !(r & (1 << (j - 1))))
        add (f[j - 1], h[j - 1], r ^ (1 << j), t);
       if (j + 1 < n && !(r & (1 << (j + 1))))
        add (f[j], h[j], r ^ (3 << j), t);
      }
    }
    g[i][j].clear ();
    for (k = 0; k < MaxH; k++)
     if (h[j][k] != -1)
     {
      g[i][j].push_back (make_pair (h[j][k], f[j][k]));
      printf ("%d %d: %d %d\n", i, j, h[j][k], f[j][k]);
      fflush (stdout);
     }
   }
   j++;
   memmove (h[n], h[j], sizeof (h[n]));
   memmove (f[n], f[j], sizeof (f[n]));
  }

  memset (ans, NA, sizeof (ans));
  k = 0;
  l = 0;
  for (i = 0; i < n; i++)
   for (j = n - i - 1; j < n; j++)
   {
    printf ("i = %d, j = %d, k = %d, l = %d\n", i, j, k, l);
    if (l & (1 << j))
    {
     printf ("filled i = %d, j = %d\n", i, j);
     l ^= 1 << j;
    }
    else if (!(k & (1 << j)))
    {
     printf ("empty  i = %d, j = %d\n", i, j);
     fflush (stdout);
     if (j - 1 >= 0 && !(k & (1 << (j - 1))))
     {
      printf ("searching for %d\n", (k ^ (1 << j)));
      for (x = g[i][j + 1].begin (); x != g[i][j + 1].end (); x++)
       printf ("element %d %d\n", x -> first, x -> second);
      for (x = g[i][j + 1].begin (); x != g[i][j + 1].end (); x++)
       if (x -> first == (k ^ (1 << j)))
        break;
      if (x == g[i][j + 1].end ())
       t = 0;
      else
       t = x -> second;
      printf ("z = %d, t = %d\n", z, t);
      fflush (stdout);
      if (z >= t)
      {
       z -= t;
       assert (j + 1 < n && !((k | l) & (1 << (j + 1))));
       ans[i    ][j    ] = 'B';
       ans[i    ][j + 1] = 'B';
       ans[i + 1][j    ] = 'B';
       k ^= 3 << j;
      }
      else
      {
       ans[i    ][j    ] = 'A';
       ans[i + 1][j - 1] = 'A';
       ans[i + 1][j    ] = 'A';
       k ^= 1 << j;
       l ^= 1 << (j - 1);
      }
     }
     else
     {
      assert (j + 1 < n && !((k | l) & (1 << (j + 1))));
      ans[i    ][j    ] = 'B';
      ans[i    ][j + 1] = 'B';
      ans[i + 1][j    ] = 'B';
      k ^= 3 << j;
     }
    }
    else
    {
     printf ("full   i = %d, j = %d\n", i, j);
     k ^= (1 << j);
    }
    out ();
   }
  assert (z == 0);
  assert (k == 0);

  for (i = 0; i < n; i++)
  {
   for (j = 0; j < n - i - 1; j++)
    putchar (' ');
   for (j = n - i - 1; j < n; j++)
   {
    assert (ans[i][j] != NA);
    putchar (ans[i][j]);
    if (j + 1 == n)
     putchar ('\n');
    else
     putchar (' ');
   }
  }
 }
 return 0;
}
