#include <cassert>
#include <cstdio>
#include <cstdlib>
#include <iostream>
#include <string>
#include <vector>

using namespace std;

const int MAX_LEN = 500000;
const char MIN_LETTER = 'a';
const char MAX_LETTER = 'z' + 2;

char buf[MAX_LEN + 1];

ostream& operator<<(ostream& out, const vector<int>& v) {
  out << "(";
  for (int i = 0; i < v.size(); ++i) {
    if (i > 0)
      out << " ";
    out << v[i];
  }
  out << ")";
  return out;
}

void BuildSuffixArray(const string& st, vector<int>* suffix_array, vector<int>* lcp) {
  int n = st.size();
  suffix_array->clear();
  suffix_array->resize(n, 0);
  vector<bool> same(n - 1, 0);

  // Sort single letters
  {
    vector<int> count(MAX_LETTER - MIN_LETTER + 1, 0);
    for (int i = 0; i < n; ++i)
      ++count[st[i] - MIN_LETTER];
    vector<int> pos(MAX_LETTER - MIN_LETTER + 1, 0);
    for (int i = 0; i <= MAX_LETTER - MIN_LETTER; ++i) {
      if (i > 0)
        pos[i] = pos[i - 1] + count[i - 1];
      for (int j = 0; j + 1 < count[i]; ++j)
        same[pos[i] + j] = true;
    }
    for (int i = 0; i < n; ++i) {
      (*suffix_array)[pos[st[i] - MIN_LETTER]++] = i;
    }
  }
  int cur_len = 1;

  // Duplicate
  while (cur_len < n) {
    vector<int> count;
    vector<int> bucket(n, 0);
    count.push_back(1);
    for (int i = 1; i < n; ++i) {
      if (same[i - 1]) {
        bucket[(*suffix_array)[i]] = count.size() - 1;
        ++count[count.size() - 1];
      } else {
        bucket[(*suffix_array)[i]] = count.size();
        count.push_back(1);
      }
    }
    vector<int> pos(count.size(), 0);
    vector<int> new_suffix_array(n, 0);
    for (int i = 1; i < count.size(); ++i)
      pos[i] = pos[i - 1] + count[i - 1];
    for (int i = 0; i < n; ++i) {
      int at = (*suffix_array)[i];
      int prev_at = at - cur_len;
      if (prev_at < 0)
        prev_at += n;
      new_suffix_array[pos[bucket[prev_at]]++] = prev_at;
    }
    for (int i = 0; i < n - 1; ++i) {
      int next_at = new_suffix_array[i] + cur_len;
      if (next_at >= n)
        next_at -= n;
      int next_at2 = new_suffix_array[i + 1] + cur_len;
      if (next_at2 >= n)
        next_at2 -= n;
      if (same[i] && bucket[next_at] != bucket[next_at2])
        same[i] = false;
    }

    cur_len *= 2;
    suffix_array->swap(new_suffix_array);
  }

  lcp->clear();
  lcp->resize(n - 1, 0);
  vector<int> inv_suffix_array(n, 0);
  for (int i = 0; i < n; ++i)
    inv_suffix_array[(*suffix_array)[i]] = i;
  int cur_lcp = 0;
  for (int i = 0; i < n; ++i) {
    int where = inv_suffix_array[i];
    if (where == n - 1)
      cur_lcp = 0;
    else {
      int next = (*suffix_array)[where + 1];
      if (cur_lcp > 0)
        --cur_lcp;
      int p1 = i + cur_lcp;
      if (p1 >= n)
        p1 -= n;
      int p2 = next + cur_lcp;
      if (p2 >= n)
        p2 -= n;
      while (st[p1] == st[p2]) {
        ++cur_lcp;
        ++p1;
        if (p1 >= n)
          p1 -= n;
        ++p2;
        if (p2 >= n)
          p2 -= n;
      }
      (*lcp)[where] = cur_lcp;
    }
  }
}

void InitDisjointSets(int n, vector<int>* parent, vector<int>* rank) {
  parent->clear();
  parent->resize(n, -1);
  rank->clear();
  rank->resize(n, 0);
}

int GetComponent(vector<int>* parent, int at) {
  if ((*parent)[at] != -1) {
    int res = GetComponent(parent, (*parent)[at]);
    (*parent)[at] = res;
    return res;
  } else {
    return at;
  }
}

void BuildMST(int n, const vector<vector<int> >& edges, int* res, vector<vector<int> >* output) {
  vector<int> parent;
  vector<int> rank;
  InitDisjointSets(n, &parent, &rank);
  *res = 0;
  for (int i = 0; i < edges.size(); ++i) {
    int a = GetComponent(&parent, edges[i][1]);
    int b = GetComponent(&parent, edges[i][2]);
    if (a != b) {
      *res += edges[i][0];
      output->push_back(edges[i]);
      if (rank[a] < rank[b]) {
        parent[a] = b;
      } else if (rank[b] < rank[a]) {
        parent[b] = a;
      } else {
        parent[a] = b;
        ++rank[b];
      }
    }
  }
  assert(output->size() == n - 1);
}

int main() {
  int n;
  scanf("%d", &n);
  fgets(buf, MAX_LEN + 1, stdin);
  vector<string> input;
  for (int i = 0; i < n; ++i) {
    fgets(buf, MAX_LEN + 1, stdin);
    input.push_back(string(buf, strlen(buf) - 1));
  }
  string all;
  vector<int> start;
  vector<int> len;
  vector<int> id;
  vector<int> to_go;
  for (int i = 0; i < n; ++i) {
    start.push_back(all.size());
    len.push_back(input[i].size());
    all += input[i];
    all += (char) ('z' + 1);
    for (int j = 0; j <= input[i].size(); ++j) {
      id.push_back(i);
      to_go.push_back(input[i].size() - j);
    }
  }
  all += (char) ('z' + 2);
  id.push_back(n - 1);
  to_go.push_back(0);
  vector<int> suffix_array;
  vector<int> lcp;
  BuildSuffixArray(all, &suffix_array, &lcp);
  vector<vector<int> > edges;
  for (int i = 0; i < all.size() - 1; ++i) {
    int len = lcp[i];
    len = min(len, to_go[suffix_array[i]]);
    vector<int> v(5, 0);
    v[0] = -len;
    v[1] = id[suffix_array[i]];
    v[2] = id[suffix_array[i + 1]];
    v[3] = input[v[1]].size() - to_go[suffix_array[i]];
    v[4] = input[v[2]].size() - to_go[suffix_array[i + 1]];
    edges.push_back(v);
  }
  sort(edges.begin(), edges.end());
  int res;
  vector<vector<int> > output;
  BuildMST(n, edges, &res, &output);
  printf("%d\n", -res);
  for (int i = 0; i < n - 1; ++i) {
    printf("%d %d %d %d %d\n", output[i][1] + 1, output[i][2] + 1, output[i][3] + 1, output[i][4] + 1, -output[i][0]);
  }
}
