#include <iostream>
#include <fstream>
#include <cstring>
#include <cassert>
#include <cstdlib>
#include <ctime>
#include <algorithm>
#include <set>

using namespace std;

const long double TL = 1.8;
const int STP = 10;

int GR()
{
	int a = rand();
	a <<= 16;
	a |= rand();
	if (a < 0) a = -a;
	if (a < 0) a = 0;
	return a;
}

const int MAXN = 100000;
const int MAXK = 1000;
const int MAXC = 1000000000;

class Seg
{
public:
	int l, r;
	int id;
};

int n, m, k;
Seg sg[MAXN];

bool operator<(const Seg &a, const Seg &b)
{
	return a.r < b.r;
}

void Load()
{
	scanf("%d%d%d", &n, &m, &k);
	assert(1 <= n && n <= MAXN);
	assert(1 <= m && m <= n);
	assert(1 <= k && k <= min(n, MAXK));
	int i;
	for (i = 0; i < n; i++)
	{
		scanf("%d%d", &sg[i].l, &sg[i].r);
		assert(-MAXC <= sg[i].l && sg[i].l <= sg[i].r && sg[i].r <= MAXC);
		sg[i].id = i;
	}
	sort(sg, sg + n);
}

int ttimes[MAXN];
int ntt;
int ttime[MAXK];
int train[MAXN];

class Event
{
public:
	int t, tp;
	int id;
};

bool operator<(const Event &a, const Event &b)
{
	if (a.t < b.t) return true;
	if (a.t > b.t) return false;
	return a.tp < b.tp;
}

Event evt[2 * MAXN + MAXK];
int ne;

int Count()
{
	ne = 0;
	int i;
	for (i = 0; i < n; i++)
	{
		evt[ne].t = sg[i].l;
		evt[ne].tp = -1; // open
		evt[ne].id = sg[i].id;
		ne++;
		evt[ne].t = sg[i].r;
		evt[ne].tp = 1; // close
		evt[ne].id = sg[i].id;
		ne++;
	}
	for (i = 0; i < k; i++)
	{
		evt[ne].t = ttime[i];
		evt[ne].tp = 0; // train
		evt[ne].id = i;
		ne++;
	}
	sort(evt, evt + ne);
	set<pair<int, int> > have;
	have.clear();
	int anum = 0;
	memset(train, 0, sizeof(train));
	for (i = 0; i < ne; i++)
	{	
		if (evt[i].tp == -1)
		{
			have.insert(make_pair(sg[evt[i].id].r, evt[i].id));
		}
		else if (evt[i].tp == 1)
		{
			have.erase(make_pair(sg[evt[i].id].r, evt[i].id));
		}
		else
		{
			int cnum = 0;
			while (cnum < m && have.size() != 0)
			{
				pair<int, int> cur = *have.begin();
				have.erase(have.begin());
				cnum++;
				anum++;
				train[cur.second] = evt[i].id + 1;
			}
		}
	}
	return anum;
}

void Solve()
{
	int i;
	ntt = n;
	for (i = 0; i < n; i++)
	{
		ttimes[i] = sg[i].r;
	}
	sort(ttimes, ttimes + ntt);
	ntt = 0;
	for (i = 1; i < n; i++)
	{
		if (ttimes[i] != ttimes[ntt])
		{
			ntt++;
			ttimes[ntt] = ttimes[i];
		}
	}
	ntt++;
	for (i = 0; i < k; i++) ttime[i] = ttimes[GR() % ntt];
	sort(ttime, ttime + k);
	clock_t start = clock();
	int stp = 0;
	int cres = Count();
	while (1)
	{
		int pos = GR() % k;
		int was = ttime[pos];
		ttime[pos] = ttimes[GR() % ntt];
		int nres = Count();
		if (nres < cres)
		{
			ttime[pos] = was;
		}
		else
		{
			cres = nres;
		}
		stp++;
		if (stp == STP)
		{
			if ((clock() - start) / CLOCKS_PER_SEC > TL) break;
			stp = 0;
		}
	}
	printf("%d\n", cres);
	for (i = 0; i < k; i++) printf("%d ", ttime[i]);
	printf("\n");
	for (i = 0; i < n; i++) printf("%d ", train[i]);
	printf("\n");
}

int main()
{
//	freopen("trains.in", "rt", stdin);
//	freopen("trains.out", "wt", stdout);
	srand(81687);
	Load();
	Solve();
	return 0;
}
