#include <cassert>
#include <algorithm>
#include <cstdio>
#include <cstdlib>
#include <iostream>
#include <stack>
#include <string>
#include <vector>

using namespace std;

ostream& operator<<(ostream& out, const vector<int>& v) {
  out << "(";
  for (int i = 0; i < v.size(); ++i) {
    if (i > 0)
      out << " ";
    out << v[i];
  }
  out << ")";
}

void Decompose(const vector<long long>& lens, int n, long long start, long long len, vector<int>* res) {
  if (start == 0 && len == lens[n]) {
    res->push_back(n);
  } else {
    long long plen = n == 0 ? 0 : lens[n - 1];
    if (start < plen) {
      Decompose(lens, n - 1, start, min(len, plen - start), res);
    }
    if (start <= plen && start + len > plen)
      res->push_back((n & 1) ? -2 : -1);
    if (n > 0 && start <= plen + 1 && start + len > plen + 1)
      res->push_back((n & 1) ? -1 : -2);
    long long pplen = n <= 1 ? 0 : lens[n - 2];
    if (start < plen + 2 + pplen && start + len > plen + 2) {
      long long nstart = max(0LL, start - plen - 2);
      long long nlen = min(pplen, start + len - plen - 2) - nstart;
      Decompose(lens, n - 2, nstart, nlen, res);
    }
    assert(n == 0 && plen + 1 + pplen == lens[n] || n > 0 && plen + 2 + pplen == lens[n]);
  }
}

vector<int> Reverse(const vector<int>& what) {
  vector<int> res;
  copy(what.rbegin(), what.rend(), back_inserter(res));
  return res;
}

bool IsPalindrome(const vector<long long>& lens, long long start, long long len) {
  int n = 0;
  while (start + len > lens[n])
    ++n;
  vector<int> first;
  Decompose(lens, n, start, len, &first);
  vector<int> second = Reverse(first);
  stack<int> first_stack;
  stack<int> second_stack;
  for (int i = 0; i < first.size(); ++i)
    first_stack.push(first[first.size() - 1 - i]);
  for (int i = 0; i < second.size(); ++i)
    second_stack.push(second[second.size() - 1 - i]);
  while (!first_stack.empty()) {
    assert(!second_stack.empty());
    int a = first_stack.top();
    first_stack.pop();
    int b = second_stack.top();
    second_stack.pop();
    if (a == 0)
      a = -1;
    if (b == 0)
      b = -1;
    if (a == b)
      continue;
    if (a < 0 && b < 0) {
      return false;
    }
    if (a < b) {
      int la = a < 0 ? 1 : lens[a];
      vector<int> remainder;
      Decompose(lens, b, la, lens[b] - la, &remainder);
      for (int i = 0; i < remainder.size(); ++i)
        second_stack.push(remainder[remainder.size() - 1 - i]);
    } else {
      int lb = b < 0 ? 1 : lens[b];
      vector<int> remainder;
      Decompose(lens, a, lb, lens[a] - lb, &remainder);
      for (int i = 0; i < remainder.size(); ++i)
        first_stack.push(remainder[remainder.size() - 1 - i]);
    }
  }
  assert(second_stack.empty());
  return true;
}

int main() {
  vector<long long> lens;
  lens.push_back(1);  // "010" without last 2
  lens.push_back(3);  // "01001" without last 2
  while (lens[lens.size() - 1] < 3100000000LL) {
    lens.push_back(lens[lens.size() - 1] + lens[lens.size() - 2] + 2);
  }
  int n;
  scanf("%d", &n);
  for (int i = 0; i < n; ++i) {
    int start;
    int len;
    scanf("%d %d", &start, &len);
    --start;
    if (IsPalindrome(lens, start, len)) {
      printf("TAK\n");
    } else {
      printf("NIE\n");
    }
  }
}
