#include <cassert>
#include <cmath>
#include <cstdio>
#include <cstdlib>
#include <cstring>
#include <iostream>
#include <sstream>
#include <string>
#include <unistd.h>
#include <vector>

using namespace std;

const int SUIT = 4, VALUE = 9, MaxBuf = 128, MaxCard = 36, NUM = 4;
char SUITS [] = "CDHS", VALUES [] = "6789TJQKA", UNKNOWN [] = "??";

int hand [NUM] [MaxCard + 1];
int table [MaxCard + 1];
bool beattable [MaxCard] [MaxCard];
bool active [NUM];
int attacker, defender, trump, curcard;

inline int get_value (int card)
{
 return card >> 2;
}

inline int get_suit (int card)
{
 return card & 3;
}

inline int get_card (int value, int suit)
{
 return (value << 2) + suit;
}

int get_card (string name)
{
 int value, suit;
 for (value = 0; value < VALUE; value++)
  if (name[0] == VALUES[value])
   break;
 for (suit = 0; suit < SUIT; suit++)
  if (name[1] == SUITS[suit])
   break;
 if (value == VALUE && suit == SUIT)
  return MaxCard;
 return get_card (value, suit);
}

string put_card (int card)
{
 if (card == MaxCard)
  return string ("NO");
 string res;
 res += VALUES[get_value (card)];
 res += SUITS[get_suit (card)];
 return res;
}

inline bool beat (int card1, int card2)
{
 return beattable[card1][card2];
}

void initbeat (void)
{
 int i, j;
 for (i = 0; i < MaxCard; i++)
  for (j = 0; j < MaxCard; j++)
  {
   bool ok;
   ok = false;
   if (get_suit (i) == get_suit (j) &&
       get_value (i) > get_value (j))
    ok = true;
   if (get_suit (i) == trump &&
       get_suit (j) != trump)
    ok = true;
   beattable[i][j] = ok;
  }
}

bool ontable (int card)
{
 int suit, value;
 value = get_value (card);
 for (suit = 0; suit < SUIT; suit++)
  if (table[get_card (value, suit)] > 0)
   return true;
 return false;
}

inline int getplayer (int num)
{
 num--;
 if (!active[num])
  num ^= 2;
 return num;
}

int main (void)
{
 char buf [MaxBuf];
 int i;
 for (i = 0; i < NUM; i++)
  active[i] = true;
 i = getpid ();
 sprintf (buf, "%08d\n", i);
 FILE * flog = fopen (buf, "wt");
 memset (hand, 0, sizeof (hand));
 memset (table, 0, sizeof (table));
 defender = 0;
 while (1)
 {
  fgets (buf, MaxBuf, stdin);
  stringstream cur (buf);
  fprintf (flog, "in:  \"%s\"\n", cur.str ().c_str ());
  fflush (flog);
  string command;
  cur >> command;

  if (command == "trump")
  {
   char temp;
   cur >> temp;
   for (trump = 0; trump < SUIT; trump++)
    if (temp == SUITS[trump])
     break;
   assert (trump < SUIT);
   initbeat ();
  }
  else if (command == "give")
  {
   string cardstr;
   int num;
   cur >> num >> cardstr;
   num = getplayer (num);
   hand[num][get_card (cardstr)]++;
  }
  else if (command == "move")
  {
   string cardstr;
   int num1, num2;
   cur >> num1 >> num2 >> cardstr;
   for (i = 0; i < MaxCard; i++)
    hand[defender][i] += table[i];
   memset (table, 0, sizeof (table));
   num1 = getplayer (num1);
   num2 = getplayer (num2);
   attacker = num1;
   defender = num2;
   curcard = get_card (cardstr);
   if (hand[num1][curcard] == 0)
    hand[num1][MaxCard]--;
   else
    hand[num1][curcard]--;
   table[curcard]++;
  }
  else if (command == "add")
  {
   string cardstr;
   int num1, num2;
   cur >> num1 >> num2 >> cardstr;
   num1 = getplayer (num1);
   num2 = getplayer (num2);
   assert (defender == num2);
   curcard = get_card (cardstr);
   if (hand[num1][curcard] == 0)
    hand[num1][MaxCard]--;
   else
    hand[num1][curcard]--;
   table[curcard]++;
  }
  else if (command == "beat")
  {
   string cardstr;
   int num, card;
   cur >> num >> cardstr;
   num = getplayer (num);
   card = get_card (cardstr);
   if (hand[num][card] == 0)
    hand[num][MaxCard]--;
   else
    hand[num][card]--;
   table[card]++;
  }
  else if (command == "take")
  {
   int num;
   cur >> num;
   num = getplayer (num);
   assert (defender == num);
  }
  else if (command == "out")
  {
   int num;
   cur >> num;
   num = getplayer (num);
   active[num] = false;
  }
  else if (command == "MOVE")
  {
   attacker = getplayer (1);
   defender = getplayer (2);
   for (i = 0; i < MaxCard; i++)
    if (hand[0][i] > 0)
     break;
   assert (i < MaxCard);
   fprintf (flog, "out:  \"%s\"\n", put_card (i).c_str ());
   fflush (flog);
   cout << put_card (i) << endl;
   fflush (stdout);
  }
  else if (command == "BEAT")
  {
   for (i = 0; i < MaxCard; i++)
    if (hand[0][i] > 0)
     if (beat (i, curcard))
      break;
   fprintf (flog, "out:  \"%s\"\n", put_card (i).c_str ());
   fflush (flog);
   cout << put_card (i) << endl;
   fflush (stdout);
  }
  else if (command == "ADD")
  {
   for (i = 0; i < MaxCard; i++)
    if (hand[0][i] > 0)
     if (ontable (i))
      break;
   fprintf (flog, "out:  \"%s\"\n", put_card (i).c_str ());
   fflush (flog);
   cout << put_card (i) << endl;
   fflush (stdout);
  }
  else
  {
   assert (false);
  }
  char ch;
  cur >> ch;
  if (ch >= 32 || !cur.eof ())
  {
   putc ('<', stderr);
   for (i = 0; i < (int) strlen (buf); i++)
    fprintf (stderr, "%02X", (int) buf[i]);
   putc ('>', stderr);
   putc ('\n', stderr);
   cerr << "ch = " << int (ch) << ", " << '"' << buf << '"' << endl;
   fflush (stderr);
   assert (false);
  }
 }
 return 0;
}
