#include <algorithm>
#include <cassert>
#include <cstdio>
#include <cstring>
#include <ctime>
#include <vector>

class Graph {
public:

	struct Arc {
		int u, v;
		Arc *rev;
		int color;
		
		Arc(int u, int v): u(u), v(v), rev(0), color(0) {
		}
	};

	Graph(int n);
	~Graph();

	void addEdge(int u, int v);
	int isLoosing();
	int isLoosing2();
	void debug();
	bool isGood();
	
	struct degreeComparator {
		
		Graph *g;
		
		degreeComparator(Graph *g) {
			this->g = g;
		}
		
		bool operator()(Graph::Arc *a1, Graph::Arc *a2) const {
			return g->degree[a1->u] + g->degree[a1->v] > g->degree[a2->u] + g->degree[a2->v];
		}
	};
	
private:

	int n;
	int num_actions;
	std::vector<Arc*> *arcs;
	bool *used;
	int *degree;
	
	void traverse(int node, int mask);
	bool connected(int mask);
	
	int solve(std::vector<Arc*>::iterator it, std::vector<Arc*>::iterator it1/*, int num_actions*/);	
	int solve2(std::vector<Arc*>::iterator it, std::vector<Arc*>::iterator it1/*, int num_actions*/);	
};

Graph::Graph(int n): n(n) {
	assert(n > 0);
	arcs = new std::vector<Arc*>[n + 1];
	used = new bool[n];	
	degree = new int[n];
}

Graph::~Graph() {
	delete[] arcs;
	delete[] used;
	delete[] degree;
}

void Graph::addEdge(int u, int v) {
	assert(1 <= u && u <= n);
	assert(1 <= v && v <= n);
	assert(u != v);
	u--;
	v--;
	Arc *uv = new Arc(u, v);
	Arc *vu = new Arc(v, u);
	uv->rev = vu;
	vu->rev = uv;
	arcs[u].push_back(uv);
	arcs[v].push_back(vu);
	degree[u]++;
	degree[v]++;
}

void Graph::traverse(int node, int mask) {
	used[node] = true;
	for (std::vector<Arc*>::iterator i = arcs[node].begin(); i != arcs[node].end(); i++) {
		Arc *a = *i;
		if (mask & (1 << a->color)) {
			if (used[a->v]) continue;
			traverse(a->v, mask);
		}
	}
}

bool Graph::connected(int mask) {
	memset(used, 0, sizeof(bool) * n);
	traverse(0, mask);
	for (int i = 0; i < n; i++) {
		if (!used[i]) {
			return false;
		}
	}
	return true;
}

int Graph::solve(std::vector<Arc*>::iterator it, std::vector<Arc*>::iterator it1/*, int num_actions*/) {
	/*
	num_actions++;
	if (num_actions >= 10000) return false;
	*/
	//if (num_actions <= 0) return false;
	if (!connected(3) || !connected(5)) {
		return 0;
	}
	/*
	memset(degree, 0, sizeof(degree));
	for (std::vector<Arc*>::iterator it0 = it; it0 != it1; it0++) {
		degree[(*it0)->u]++;
		degree[(*it0)->v]++;
	}
	*/
	//sort(it, it1, degreeComparator(this));
	if (it == it1) {
		/*
		printf("graph test {\n");
		for (int i = 0; i < n; i++) {
			for (std::vector<Arc*>::iterator it = arcs[i].begin(); it != arcs[i].end(); it++) {
				Arc *a = *it;
				//if (a->color != 1) continue;
				if (a->u < a->v) printf("%d--%d [ color = \"%s\" ]\n", a->u + 1, a->v + 1, (a->color == 1) ? "red" : "green");
			}
		}
		printf("}\n");
		*/
		//total++;
		return 1;
	}
	Arc *a = *it;
	memset(used, 0, sizeof(bool) * n);
	traverse(a->u, 2);
//	num_actions--;
	int res = 0;
	if (!used[a->v]) {
		a->color = 1;
		a->rev->color = 1;
		//int cur = num_actions / 2;
		//if (solve(it + 1, it1/*, cur*/)) return true;
		res += solve(it + 1, it1);
		//num_actions -= cur;
		a->color = 0;
		a->rev->color = 0;
	}
	a->color = 2;
	a->rev->color = 2;
	//if (solve(it + 1, it1/*, num_actions*/)) return true;
	res += solve(it + 1, it1);
	a->color = 0;
	a->rev->color = 0;
	return res;
}

int Graph::solve2(std::vector<Arc*>::iterator it, std::vector<Arc*>::iterator it1/*, int num_actions*/) {
	/*
	num_actions++;
	if (num_actions >= 10000) return false;
	*/
	//if (num_actions <= 0) return false;
	if (!connected(3)) {
		return 0;
	}
	/*
	memset(degree, 0, sizeof(degree));
	for (std::vector<Arc*>::iterator it0 = it; it0 != it1; it0++) {
		degree[(*it0)->u]++;
		degree[(*it0)->v]++;
	}
	*/
	//sort(it, it1, degreeComparator(this));
	if (it == it1) {
		/*
		printf("graph test {\n");
		for (int i = 0; i < n; i++) {
			for (std::vector<Arc*>::iterator it = arcs[i].begin(); it != arcs[i].end(); it++) {
				Arc *a = *it;
				//if (a->color != 1) continue;
				if (a->u < a->v) printf("%d--%d [ color = \"%s\" ]\n", a->u + 1, a->v + 1, (a->color == 1) ? "red" : "green");
			}
		}
		printf("}\n");
		*/
		//total++;
		return 1;
	}
	Arc *a = *it;
	memset(used, 0, sizeof(bool) * n);
	traverse(a->u, 2);
//	num_actions--;
	int res = 0;
	if (!used[a->v]) {
		a->color = 1;
		a->rev->color = 1;
		//int cur = num_actions / 2;
		//if (solve(it + 1, it1/*, cur*/)) return true;
		res += solve2(it + 1, it1);
		//num_actions -= cur;
		a->color = 0;
		a->rev->color = 0;
	}
	a->color = 2;
	a->rev->color = 2;
	//if (solve(it + 1, it1/*, num_actions*/)) return true;
	res += solve2(it + 1, it1);
	a->color = 0;
	a->rev->color = 0;
	return res;
}

int get(int *p, int x) {
	if (p[x] != x) p[x] = get(p, p[x]);
	return p[x];
}

int Graph::isLoosing() {
	std::vector<Arc*> allArcs;
	for (int i = 0; i < n; i++) {
		for (std::vector<Arc*>::iterator it = arcs[i].begin(); it != arcs[i].end(); it++) {
			Arc *a = *it;
			a->color = 0;
			if (a->u < a->v) {
				allArcs.push_back(a);
			}
		}
	}
	assert(connected(1));
	//std::random_shuffle(allArcs.begin(), allArcs.end());
	//std::sort(allArcs.begin(), allArcs.end(), degreeComparator(this));
	/*
	int *p = new int[n];
	for (;;) {
		std::random_shuffle(allArcs.begin(), allArcs.end());
		for (int i = 0; i < n; i++) {
			p[i] = i;
		}
		for (int i = 0; i < int(allArcs.size()); i++) {
			allArcs[i]->color = 0;
			allArcs[i]->rev->color = 0;
			int u = get(p, allArcs[i]->u);
			int v = get(p, allArcs[i]->v);
			if (u == v) continue;
			allArcs[i]->color = 1;
			allArcs[i]->rev->color = 1;
			p[u] = v;
		}
		if (connected(1) && connected(2)) break;
	}
	delete[] p;
	*/
	return solve(allArcs.begin(), allArcs.end());
	/*
	num_actions = 0;
	bool result = solve(allArcs.begin(), allArcs.end());
	fprintf(stderr, "%d\n", num_actions);
	return result;
	*/
}

int Graph::isLoosing2() {
	std::vector<Arc*> allArcs;
	for (int i = 0; i < n; i++) {
		for (std::vector<Arc*>::iterator it = arcs[i].begin(); it != arcs[i].end(); it++) {
			Arc *a = *it;
			a->color = 0;
			if (a->u < a->v) {
				allArcs.push_back(a);
			}
		}
	}
	assert(connected(1));
	//std::random_shuffle(allArcs.begin(), allArcs.end());
	//std::sort(allArcs.begin(), allArcs.end(), degreeComparator(this));
	/*
	int *p = new int[n];
	for (;;) {
		std::random_shuffle(allArcs.begin(), allArcs.end());
		for (int i = 0; i < n; i++) {
			p[i] = i;
		}
		for (int i = 0; i < int(allArcs.size()); i++) {
			allArcs[i]->color = 0;
			allArcs[i]->rev->color = 0;
			int u = get(p, allArcs[i]->u);
			int v = get(p, allArcs[i]->v);
			if (u == v) continue;
			allArcs[i]->color = 1;
			allArcs[i]->rev->color = 1;
			p[u] = v;
		}
		if (connected(1) && connected(2)) break;
	}
	delete[] p;
	*/
	return solve2(allArcs.begin(), allArcs.end());
	/*
	num_actions = 0;
	bool result = solve(allArcs.begin(), allArcs.end());
	fprintf(stderr, "%d\n", num_actions);
	return result;
	*/
}

void Graph::debug() {
	printf("graph test {\n");
	for (int i = 0; i < n; i++) {
		for (std::vector<Arc*>::iterator it = arcs[i].begin(); it != arcs[i].end(); it++) {
			Arc *a = *it;
			//if (a->color != 1) continue;
			if (a->u < a->v) printf("%d--%d\n", a->u + 1, a->v + 1);
		}
	}
	printf("}\n");
}

bool Graph::isGood() {
	std::vector<std::pair<int, int> > indices;
	for (int i = 0; i < n; i++) {
		for (std::vector<Arc*>::iterator it = arcs[i].begin(); it != arcs[i].end(); it++) {
			Arc *a = *it;
			a->color = 0;
			if (a->u < a->v) {
				indices.push_back(std::make_pair(std::min(a->u, a->v), std::max(a->u, a->v)));
			}
		}
	}
	std::sort(indices.begin(), indices.end());
	for (int i = 0; i < int(indices.size()) - 1; i++) {
		if (indices[i] == indices[i + 1]) return false;
	}
	std::vector<int> degree(n);
	for (int i = 0; i < int(indices.size()); i++) {
		degree[indices[i].first]++;
		degree[indices[i].second]++;
	}
	for (int i = 0; i < n; i++) {
		if (degree[i] < 3) return false;
	}
	return true;
}

int main() {
	/*
	freopen("output.txt", "w", stdout);
	srand(0xdead);
	Graph g(50);
	for (int i = 0; i < 300; i++) {
		for (;;) {
			int u = rand() % 50 + 1;
			int v = rand() % 50 + 1;
			if (u == v) continue;
			g.addEdge(u, v);
			break;
		}
	}
	for (int i = 0; i < 100; i++) {
		printf("%d\n", g.isLoosing());
	}
	*/
	/*
	Graph g(6);
	g.addEdge(1, 2);
	g.addEdge(2, 3);
	g.addEdge(3, 4);
	g.addEdge(4, 5);
	g.addEdge(5, 6);
	g.addEdge(6, 1);
	g.addEdge(1, 4);
	g.addEdge(2, 5);
	g.addEdge(3, 6);
	g.addEdge(3, 4);
	printf("%d %d\n", g.isLoosing(), g.isLoosing2());
	*/
	#define PARAM 50
	srand(time(NULL));
	freopen("output.txt", "w", stdout);
	double minp = 1.0, maxp = 0.0;
	for (;;) {
		Graph g(PARAM);
		for (int i = 2; i <= PARAM; i++) {
			int j = rand() % (i - 1) + 1;
			g.addEdge(i, j);
		}
		std::vector<int> p(PARAM);
		for (int i = 0; i < PARAM; i++) {
			p[i] = i;
		}
		std::random_shuffle(p.begin(), p.end());
		for (int i = 1; i < PARAM; i++) {
			int j = rand() % i;
			g.addEdge(p[i] + 1, p[j] + 1);
		}
		if (!g.isGood()) continue;
		fprintf(stderr, "generated\n");
		int a = g.isLoosing();
		int b = g.isLoosing2();
		if ((a + 0.0) / (b + 0.0) < minp) {
			g.debug();
			printf("characteristics: %d %d\n", a, b);
			fflush(stdout);
		}
		minp = std::min(minp, (a + 0.0) / (b + 0.0));
		maxp = std::max(maxp, (a + 0.0) / (b + 0.0));
		fprintf(stderr, "%.10lf %.10lf %.10lf\n", minp, maxp, maxp / minp);
	}
	/*
	for (int i = 0; i < 1000; i++) {
		bool res = g.isLoosing();
		fprintf(stderr, "result: %d\n", res);
		if (res) break;
	}
	*/
	/*
	freopen("input.txt", "r", stdin);
	freopen("output.txt", "w", stdout);
	int n, m;
	scanf("%d%d", &n, &m);
	Graph g(n);
	for (int i = 0; i < m; i++) {
		int u, v;
		scanf("%d%d", &u, &v);
		g.addEdge(u, v);
	}
	for (int i = 0; i < 100; i++) {
		printf("%d\n", g.isLoosing());
	}
	*/
	return 0;
}
