#include <cstdio>
#include <cstdlib>
#include <algorithm>
#include <vector>
#include <list>
#include <string>
#include <iostream>
#include <assert.h>

using namespace std;

const int BASE = 31;

#ifdef DEBUG
int eprintf(const char* format, ...) {
  va_list args;
  va_start(args, format);
  int ret = vfprintf(stderr, format, args);
  va_end(args);
  return ret;
}
#endif

typedef unsigned char byte;
typedef vector<short> bigint;

#ifdef DEBUG
void eprintbi(bigint &x) {
  eprintf("{");
  for (int i = x.size() - 1; i >= 0; i--) {
    eprintf("%d", x[i]);
    if (i) eprintf(",");
  }
  eprintf("}");
}
#endif

void offset(bigint &x, int new_dig) {
  x.resize(x.size() + 1);
  for (int i = x.size() - 1; i > 0; i--) x[i] = x[i - 1];
  x[0] = new_dig;
}

int comp(bigint a, bigint b) {
  if (a.size() > b.size()) return -1;
  if (a.size() < b.size()) return 1;
  for (int i = a.size() - 1; i >= 0; i--) {
    if (a[i] > b[i]) return -1;
    if (a[i] < b[i]) return 1;
  }
  return 0;
}

void sub(bigint a, bigint b, bigint &res) {
  if (comp(a, b) == 1) assert(!"There is negative big integers in this program");
  res = bigint(a.size());
  
  int c = 0;
  for (int i = 0; i < a.size(); i++) {
    c += a[i];
    if (i < b.size()) c -= b[i];
    res[i] = c;
    while (res[i] < 0) res[i] += BASE, c -= BASE;
    c /= BASE;
  }
  while (res.size() && !res[res.size() - 1]) res.resize(res.size() - 1);
}

void multi(bigint a, byte b, bigint &res) {
  res = bigint(a.size());
  int c = 0;
  for (int i = 0; i < a.size(); i++) {
    c += a[i] * b;
    res[i] = c % BASE;
    c /= BASE;
  }
  if (c) {
    res.resize(res.size() + 1);
    res[res.size() - 1] = c;
  }
}

byte small_divide(bigint a, bigint b, bigint &rem) {
  int near = 0;
  if (a.size() == b.size()) near = a[a.size() - 1] / b[b.size() - 1];
  else if (a.size() == b.size() + 1) {
    near = a[a.size() - 1] * BASE + a[a.size() - 2];
    near /= b[b.size() - 1];
    if (near >= BASE) near = BASE - 1;
  } else assert(!"No WTF.");
  
  bigint tmp, tmp2;
  multi(b, near, tmp);
  while (comp(a, tmp) == 1) { sub(tmp, b, tmp2); tmp2.swap(tmp); near--; }
  sub(a, tmp, rem);
  return near;
}

void divide(bigint a, bigint b, bigint &res) {
  bigint rem;
  
  res = bigint();
  
  int pos = a.size();
  for (int i = 0; i < b.size(); i++) offset(rem, a[--pos]);
  while (pos >= 0) {
    bool cont = true;
    while (comp(rem, b) == 1) {
      if (pos < 0) { cont = false; break; }
      offset(rem, a[--pos]);
    }
    if (!cont) break;
    
    bigint tmp;
    #ifdef DEBUG
    eprintf("Rem="); eprintbi(rem); eprintf("\n");
    eprintf("B="); eprintbi(b); eprintf("\n");
    #endif
    offset(res, small_divide(rem, b, tmp));
    #ifdef DEBUG
    eprintf("Res="); eprintbi(res); eprintf("\n");
    eprintf("\n");
    #endif
    rem.swap(tmp); tmp = bigint();
  }
}

int main() {
  {
    FILE *f = fopen("/dev/urandom", "rb");
    if (f) {
      int x;
      fread(&x, sizeof(x), 1, f);
      srand(x);
      fclose(f);
    }
  }
#ifdef DEBUG
  freopen("input.txt", "r", stdin);
  freopen("output.txt", "w", stdout);
#endif

  bigint a, b;
  string str;
  
  int i = 0; getline(cin, str); a = bigint(str.size());
  for (int i2 = str.size() - 1; i2 >= 0; i2--, i++)
    if ((str[i2] >= '0') && (str[i2] <= '9'))
      a[i] = str[i2] - '0';
    else if ((str[i2] >= 'A') && (str[i2] <= 'Z'))
      a[i] = str[i2] - 'A' + 10;
    else
      assert(!"Test is invalid");
      
  i = 0; getline(cin, str); b = bigint(str.size());
  for (int i2 = str.size() - 1; i2 >= 0; i2--, i++)
    if ((str[i2] >= '0') && (str[i2] <= '9'))
      b[i] = str[i2] - '0';
    else if ((str[i2] >= 'A') && (str[i2] <= 'Z'))
      b[i] = str[i2] - 'A' + 10;
    else
      assert(!"Test is invalid");

  int k; scanf("%d", &k);
  
  bigint c; divide(a, b, c);
  while (!c[c.size() - 1]) c.resize(c.size() - 1);
  if (c.size() > k) c.resize(k);
  
  for (int i = 0; i < k - c.size(); i++) printf("0");
  for (int i = c.size() - 1; i >= 0; i--)
    if ((c[i] >= 0) && (c[i] <= 9))
      printf("%c", c[i] + '0');
    else if ((c[i] >= 10) && (c[i] <= 30))
      printf("%c", c[i] - 10 + 'A');
    else
      assert(!"Program is not crashed");
  printf("\n");
  return 0;
}
