#include <cstdio>
#include <cstdlib>
#include <algorithm>
#include <vector>
#include <list>
#include <string>
#include <set>
#include <iostream>
#include <assert.h>

using namespace std;

#ifdef DEBUG
int eprintf(const char* format, ...) {
  va_list args;
  va_start(args, format);
  int ret = vfprintf(stderr, format, args);
  va_end(args);
  return ret;
}
#endif

// ----------     CARTESIAN TREE    ----------
template<typename TKey, typename TData> class cart_tree {
  private:
  typedef struct _node {
    TKey x; int y;
    set<TData> data;
    _node *l, *r;
    
    _node(TKey _x, TData _data) {
      x = _x;
      data = set<TData>(); data.insert(_data);
      y = rand();
      l = r = 0;
    }
  } *node;
  node root;
  
  /*int gCount(node x) { return x ? x->count : 0; }
  int reCount(node x) {
    if (!x) return;
    x->count = gCount(x->l) + gCount(x->r);
  }*/
  
  node merge(node a, node b) {
    if (!a) return b;
    if (!b) return a;
    if (a->y <= b->y) {
      a->r = merge(a->r, b);
      //reCalc(a);
      return a;
    } else {
      b->l = merge(a, b->l);
      //reCalc(b);
      return b;
    }
  }
  
  void split(node t, TKey x, node &l, node &r) {
    if (!t) { l = 0; r = 0; return; }
    if (t->x == x) { l = t; r = t->r; t->r = 0; /*reCalc(t);*/ return; }
    if (x < t->x) {
      r = t;
      split(t->l, x, l, t->l);
      //reCalc(t);
    } else {
      l = t;
      split(t->r, x, t->r, r);
      //reCalc(t);
    }
  }
  
  node _find(TKey x, node *par = 0) {
    node cur = root;
    if (par) *par = 0;
    for (; cur;) {
      if (cur->x == x) return cur;
      if (par) *par = cur;
      if (x < cur->x) cur = cur->l;
      else cur = cur->r;
    }
    return 0;
  }
  
  public:  
  #ifdef DEBUG
  void dbgprint(node x, int off) {
    if (!x) return;
    
    for (int i = 0; i < off; i++) printf(" ");
    printf("@(%d)", x); fflush(stdout);
    printf("%d {", x->x);
    typeof(x->data.begin()) it = x->data.begin();
    for (; it != x->data.end(); it++)
      printf(" %d", *it);
    printf("}\n");
    
    for (int i = 0; i < off; i++) printf(" "); printf("LEFT:\n");
    dbgprint(x->l, off + 2);
    fflush(stdout);
    for (int i = 0; i < off; i++) printf(" "); printf("RIGHT:\n");
    dbgprint(x->r, off + 2);
    fflush(stdout);
    for (int i = 0; i < off; i++) printf(" "); printf("---\n");
    fflush(stdout);
  }
  void dbgprint() {
    printf("---------- TREE ----------\n");
    dbgprint(root, 0);
  }
  #endif  
  
  cart_tree() { root = 0; }
  void insert(TKey x, TData data) {
    if (node cur = _find(x)) {
      cur->data.insert(data);
      return;
    }
    node l, r;
    split(root, x, l, r);
      
    node n = new _node(x, data);
    root = merge(l, n);
    root = merge(root, r);
  }
  void erase(TKey x) {
    node cur, par;
    cur = _find(x, &par);
    if (!cur) return;
    
    if (par)
      if (par->l == cur) {
        par->l = merge(cur->l, cur->r);
      } else {
        par->r = merge(cur->l, cur->r);
      }
    else
      root = merge(cur->l, cur->r);
    delete cur;
  }
  void erase(TKey x, TData data) {
    node cur, par;
    cur = _find(x, &par);
    if (!cur) return;
    
    cur->data.erase(data);
    if (!cur->data.size()) {
      if (par)
        if (par->l == cur) {
          par->l = merge(cur->l, cur->r);
        } else {
          par->r = merge(cur->l, cur->r);
        }
      else
        root = merge(cur->l, cur->r);
      delete cur;
    }
  }
  set<TData> find(TKey x) {
    if (node cur = _find(x)) return cur->data;
    else return set<TData>();
  }
};
// ---------- END OF CARTESIAN TREE ----------

#define eq(a, b) (((a) == (b)) || ((a) == '?') || ((b) == '?'))

int main() {
  {
    FILE *f = fopen("/dev/urandom", "rb");
    if (f) {
      int x;
      fread(&x, sizeof(x), 1, f);
      srand(x);
      fclose(f);
    }
  }
  srand(239);
#ifdef DEBUG
  freopen("input.txt", "r", stdin);
  freopen("output.txt", "w", stdout);
#endif

  string str;
  getline(cin, str);
  int n = str.size();

  int pos = 0;
  vector<int> pals((n << 1) - 1);
  cart_tree<int, int> bads;
  for (int i = 0; i < n; i++) {
    pals[pos] = 1;
    int a = i - 1, b = i + 1;
    while ((a >= 0) && (b < n)) {
      if (!eq(str[a], str[b])) break;
      a--, b++; pals[pos]++;
    }
    if ((a >= 0) && (b < n))
      bads.insert(a, pos),
      bads.insert(b, pos);
    pos++;
    
    if (i + 1 >= n) continue;
    pals[pos] = 0;
    a = i, b = i + 1;
    while ((a >= 0) && (b < n)) {
      if (!eq(str[a], str[b])) break;
      a--, b++; pals[pos]++;
    }
    if ((a >= 0) && (b < n))
      bads.insert(a, pos),
      bads.insert(b, pos);
    pos++;
  }
  int cur_ans = 0;
  for (int i = 0; i < pals.size(); i++) cur_ans += pals[i];
  printf("%d\n", cur_ans); fflush(stdout);
  for (int i = 0; i < n; i++) {
    #ifdef DEBUG
    bads.dbgprint();
    #endif
    
    int k; scanf("%d", &k); k--;
    str[k] = '?';
    set<int> bad_pals = bads.find(k);
    
    #ifdef DEBUG
    eprintf("After str[%d]='?':\n", k);
    #endif
    for (set<int>::iterator it = bad_pals.begin(); it != bad_pals.end(); it++) {
      #ifdef DEBUG
      eprintf("  %d\n", *it);
      #endif
      int a, b, pal_pos = *it >> 1;
      if (*it & 1) {
        a = pal_pos - pals[*it];
        b = pal_pos + 1 + pals[*it];
      } else {
        a = pal_pos - pals[*it];
        b = pal_pos + pals[*it];
      }
      assert((a == k) || (b == k));
      bads.erase(a, *it); bads.erase(b, *it);
      while ((a >= 0) && (b < n)) {
        if (!eq(str[a], str[b])) break;
        a--, b++; pals[*it]++; cur_ans++;
      }
      if ((a >= 0) && (b < n))
        bads.insert(a, *it),
        bads.insert(b, *it);
    }
    
    printf("%d\n", cur_ans); fflush(stdout);
  }

  return 0;
}
