#include <cstdio>
#include <cstdlib>
#include <algorithm>
#include <vector>
#include <list>
#include <string>
#include <assert.h>

using namespace std;
typedef unsigned char byte;

#ifdef DEBUG
int eprintf(const char* format, ...) {
  va_list args;
  va_start(args, format);
  int ret = vfprintf(stderr, format, args);
  va_end(args);
  return ret;
}

int offset = 0;
int eoprintf(const char* format, ...) {
  for (int i = 0; i < offset; i++) fprintf(stderr, " ");
  va_list args;
  va_start(args, format);
  int ret = vfprintf(stderr, format, args);
  va_end(args);
  return ret;
}
#endif

#define IsCacheAvailable(y) ((y >= 3) && (y <= 17))
int **_cache[15]; // y = 3..17. 18..21 calculating always
inline int get_cache(byte y, byte x, int profile) {
  if (!IsCacheAvailable(y)) return -1;
  return _cache[y - 3][x][profile];
}
inline int set_cache(byte y, byte x, int profile, int val) {
  assert(IsCacheAvailable(y));
  return _cache[y - 3][x][profile] = val;
}
inline int add_cache(byte y, byte x, int profile, int val) {
  if (_cache[y - 3][x][profile] < 0) _cache[y - 3][x][profile] = val;
  else _cache[y - 3][x][profile] += val;
  return _cache[y - 3][x][profile] < 0;
}

int n, last_profile;

#define old_profile(profile, x) !!(profile & (1 << (x + 1)))
//#define old_profile_up(profile, x) (profile | (1 << (x + 1)))
//#define old_profile_dn(profile, x) (profile & ~(1 << (x + 1)))

#define new_profile(profile, x) !!(profile & (1 << x))
#define new_profile_up(profile, x) (profile | (1 << x))
#define new_profile_dn(profile, x) (profile & ~(1 << x))

// Profile structure with y=3:
//   ? ? X 4
//  0 1 2 ? ?

#ifdef DEBUG
void eoprintprof(byte y, byte x, int profile) {
  eoprintf(" ");
  for (int i = 0; i < x; i++) eprintf(" ?");
  eprintf(" O");
  for (int i = x + 1; i <= y; i++) eprintf(" %c", old_profile(profile, i) ? 'X' : '.');
  eprintf("\n");
  
  eoprintf("");
  for (int i = 0; i <= x; i++) eprintf(" %c", new_profile(profile, i) ? 'X' : '.');
  for (int i = x + 1; i <= y + 1; i++) eprintf(" ?");
  eprintf("\n");
}
#endif

int cur_cnt = 0;
int dfs(byte y, byte x, int profile) {
  if (x > y) { x = 0; y++; profile <<= 1; }
  if (y == (n - 1)) return !!(profile == last_profile);
  if (y == n) return !profile;
  
  if (get_cache(y, x, profile) >= 0)
    return get_cache(y, x, profile);
  if (old_profile(profile, x))
    if (IsCacheAvailable(y))
      return set_cache(y, x, profile, dfs(y, x + 1, new_profile_dn(profile, x + 1)));
    else
      return dfs(y, x + 1, new_profile_dn(profile, x + 1));
  
  int cur = 0;
  if ((x + 1 <= y) &&
      !old_profile(profile, x + 1) &&
      !(!new_profile(profile, x) && (y == (n - 2))) ) {
    cur += dfs(y, x + 2, new_profile_dn(new_profile_up(profile, x + 1), x + 2));
  }
  if (!new_profile(profile, x)) {
    cur += dfs(y, x + 1, new_profile_up(new_profile_up(profile, x), x + 1));
  }
  if (IsCacheAvailable(y)) return set_cache(y, x, profile, cur);
  else return cur;
}

vector< vector<char> > field;
const char chars[] = {'?', 'A', 'B'};

int k;
void dfs_save(byte y, byte x, int profile) {
  if (x > y) { x = 0; y++; profile <<= 1; }
  if (y >= (n - 1)) return;
  
  if (old_profile(profile, x)) {
    dfs_save(y, x + 1, new_profile_dn(profile, x + 1));
    return;
  }
  
  if (!new_profile(profile, x)) {
    int cnt = dfs(y, x + 1, new_profile_up(new_profile_up(profile, x), x + 1));
    if (cnt <= k) k -= cnt;
    else {
      field[y][x] = field[y + 1][x] = field[y + 1][x + 1] = 1;
      dfs_save(y, x + 1, new_profile_up(new_profile_up(profile, x), x + 1));
      return;
    }
  }
  if ((x + 1 <= y) &&
      !old_profile(profile, x + 1) &&
      !(!new_profile(profile, x) && (y == (n - 2))) ) {
    
    int cnt = dfs(y, x + 2, new_profile_dn(new_profile_up(profile, x + 1), x + 2));
    if (cnt <= k) k -= cnt;
    else {
      field[y][x] = field[y][x + 1] = field[y + 1][x + 1] = 2;
      dfs_save(y, x + 2, new_profile_dn(new_profile_up(profile, x + 1), x + 2));
      return;
    }
  }
}

int main() {
  {
    FILE *f = fopen("/dev/urandom", "rb");
    if (f) {
      int x;
      fread(&x, sizeof(x), 1, f);
      srand(x);
      fclose(f);
    }
  }
#ifdef DEBUG
  freopen("input.txt", "r", stdin);
  freopen("output.txt", "w", stdout);

  while (scanf("%d", &n) != EOF) {
#else
    scanf("%d", &n);
#endif
    scanf("%d", &k);
    field = vector< vector<char> >(n);
    for (int i = 0; i < n; i++) field[i] = vector<char>(i + 1, 0);
    
    for (int i = 0; i < min(n - 3, 15); i++) {
      _cache[i] = new int*[i + 4];
      for (int i2 = 0; i2 < i + 4; i2++) {
        _cache[i][i2] = new int[1 << (i + 5)];
        memset(_cache[i][i2], -1, sizeof(int) * (1 << (i + 5)));
        /*for (int i3 = 0; i3 < (1 << (i + 5)); i3++)
          _cache[i][i2][i3] = -1;*/
      }
      #ifdef DEBUG
      eprintf("%d/%d blocks allocated\n", i + 1, min(n - 3, 15));
      #endif
    }
    last_profile = ((1 << n) - 1) << 1;
    
    int total_count = dfs(2, 0, 0);
    field[0][0] = field[1][0] = field[1][1] = 1;
    #ifdef DEBUG
    if (k >= 0) {
    #endif
      dfs_save(2, 0, 0);
      for (int i = 0; i < n; i++) {
        for (int i2 = 0; i2 < n - i; i2++) printf(" ");
        for (int i2 = 0; i2 <= i; i2++) {
          if (i2) printf(" ");
          printf("%c", chars[field[i][i2]]);
        }
        printf("\n");
      }
    #ifdef DEBUG
    } else {
      printf("%d\n", total_count);
    }
    #endif
    
    for (int i = 0; i < min(n - 3, 15); i++) {
      for (int i2 = 0; i2 < i + 4; i2++)
        delete[] _cache[i][i2];
      delete[] _cache[i];
      #ifdef DEBUG
      eprintf("%d/%d blocks deallocated\n", i + 1, min(n - 3, 15));
      #endif
    }
#ifdef DEBUG
  }
#endif
  return 0;
}

