#include <iostream>
#include <vector>
#include <stdlib.h>

using namespace std;

const int maxn=1000010;
const int inf =-1;
const int WHITE=0;
const int GREY=1;
const int BLACK=2;

struct edge
{
	int x, w, id;
	bool enab;
	edge* next;
};

struct Node
{
	int val;
	int id;
	int heappos;
	Node();
};

Node::Node()
{
	this->val=-1; this->id=-1;
	this->heappos=-1;
}

typedef Node* PNode;


void swap(PNode &a, PNode &b)
{
	PNode c;
	swap(a->heappos,b->heappos);
	c=a;
	a=b;
	b=c;
}

struct Heap
{
	int size;
	PNode el[maxn];
	Heap();
	void Heapify(int x);
	void Up(int x);
	PNode Insert(int d, int id);
	void DeleteMin();
	PNode GetMin();
	void Update(int x, int val);
};

bool less2(PNode a,PNode b)
{
	if (a->val==inf)
		return false;
	if (b->val==inf)
		return true;
	return (a->val<b->val);
}

Heap::Heap()
{
	this->size=0;
}

void Heap::Heapify(int x)
{
	int l=(x+1)*2-1,r=(x+1)*2+1-1, min=x;
	if (l<this->size)
		if (less2(this->el[l],this->el[min]))
			min=l;
	if (r<this->size)
		if (less2(this->el[r],this->el[min]))
			min=r;
	
	if (min!=x)
	{
		swap(this->el[x],this->el[min]);
		this->Heapify(min);
	}
}

void Heap::Up(int x)
{
	int p = (x+1)/2-1;
	while (x>0)
		if (less2(this->el[x],this->el[p]))
		{
			swap(this->el[x],this->el[p]);
			x=p;
			p=(x+1)/2-1;
		}
		else
			return;
}

PNode Heap::Insert(int d, int id)
{
	PNode buf = new Node;
	buf->val=d;
	buf->id=id;
	buf->heappos=this->size;
	this->el[this->size++]=buf;
	this->Up(this->size-1);
	return buf;
}

void Heap::DeleteMin()
{
	swap(this->el[0],this->el[this->size-1]);
	this->size--;
	this->Heapify(0);
}

PNode Heap::GetMin()
{
	return this->el[0];
}

void Heap::Update(int x, int val)
{
	this->el[x]->val=val;
	this->Heapify(x);
	this->Up(x);
}


edge* E[maxn];
edge* Erev[maxn];
int stepIn[maxn];
int stepOut[maxn];
PNode d[maxn];
edge* ped[maxn];
char used[maxn];
int pver[maxn];
Heap h;
int n,m1,m2,s=0,t=0;

void AddEdge(int a,int b, int w, bool enab, int id)
{
	edge * t = new edge;
	t->x=b;
	t->enab=enab;
	t->w=w;
	t->id=id;
	t->next=E[a];
	E[a]=t;
}

void AddEdgeRev(int a,int b, int w, bool enab, int id)
{
	edge * t = new edge;
	t->x=b;
	t->enab=enab;
	t->w=w;
	t->id=id;
	t->next=Erev[a];
	Erev[a]=t;
}

void Deijkstra(int start)
{
	for (int i=0; i<n; i++)
		if (i!=start)
			d[i]=h.Insert(inf,i);
	
	d[start] = h.Insert(0,start);
	
	while (h.size)
	{
		PNode cur = h.GetMin();
		h.DeleteMin();
		
		for (edge * t= E[cur->id];t;t=t->next)
			if ((d[t->x]->val==inf) || (d[t->x]->val>(d[cur->id]->val+t->w)))
			{
				h.Update(d[t->x]->heappos,d[cur->id]->val+t->w);
				ped[t->x]=t;
				pver[t->x]=cur->id;
			}
	}
}

vector<int> ans;

void SaveAns(int x)
{
	if (pver[x]==inf)
		return;
	if (!ped[x]->enab)
		ans.push_back(ped[x]->id);
	SaveAns(pver[x]);
}

void DFS1(int x, int add)
{
	used[x]=GREY;
	stepIn[x]=add+1;
	
	for (edge* t=E[x]; t; t=t->next)
		if (used[t->x]==WHITE)
		{
			DFS1(t->x,add+1);
		} else if (used[t->x]==GREY)
		{
			stepIn[t->x]=add+1;
		} else if (used[t->x]==BLACK)
		{
			stepIn[t->x]+=add+1;
		}
	used[x]=BLACK;
}

void DFS2(int x, int add)
{
	used[x]=GREY;
	stepOut[x]=add+1;
	
	for (edge* t=Erev[x]; t; t=t->next)
		if (used[t->x]==WHITE)
	{
		DFS1(t->x,add+1);
	} else if (used[t->x]==GREY)
	{
		stepOut[t->x]=add+1;
	} else if (used[t->x]==BLACK)
	{
		stepOut[t->x]+=add+1;
	}
	used[x]=BLACK;
}

int main()
{
	memset(E,0,sizeof(E));
	memset(Erev,0,sizeof(Erev));
	memset(stepIn,0,sizeof(stepIn));
	memset(stepOut,0,sizeof(stepOut));
	//memset(d,0,sizeof(d));
	memset(ped,0,sizeof(ped));
	ans.clear();
	for (int i=0; i<maxn; i++)
		pver[i]=inf, used[i]=WHITE;
	
	cin >> n >> m1;
	
	for (int i=0; i<m1; i++)
	{
		int a,b,w=0;
		cin >> a >> b;
		a--; b--;
		AddEdge(a,b,w,true,-1);
		AddEdgeRev(b,a,w,true,-1);
	}
	
	for(int i=0;i<n; i++)
		if(!used[i])
			DFS1(i,0);
	
	for (int i=0; i<n;  i++)
		used[i]=WHITE;
	
	for(int i=0;i<n; i++)
		if (!used[i])
			DFS2(i,0);
	
	int maxid=0;
	for (int i=0;i<n; i++)
		if (stepIn[i]>stepIn[maxid])
			maxid=i;
	t=maxid;
	
	maxid=0;
	for (int i=0;i<n; i++)
		if (stepOut[i]>stepOut[maxid])
			maxid=i;
	s=maxid;
	
	cin >> m2;
	
	for (int i=0; i<m2; i++)
	{
		int a,b,w;
		cin >> a >> b >> w;
		a--, b--;
		AddEdge(a,b,w,false,i);
	}
	
	Deijkstra(t);
	
	if (d[s]->val==-1)
		cout << "NO";
	else
	{
		cout << "YES" << endl;
		cout << d[s]->val << endl;
		SaveAns(s);
		cout << ans.size() << endl;
		for (int i=0; i<ans.size(); i++)
			cout << ans[i]+1 << ' ';
	}
}