#include <cstdio>
#include <cstdlib>
#include <algorithm>
#include <vector>
#include <list>
#include <string>
#include <assert.h>
#include <iostream>

using namespace std;

#ifdef DEBUG
int eprintf(const char* format, ...) {
  va_list args;
  va_start(args, format);
  int ret = vfprintf(stderr, format, args);
  va_end(args);
  return ret;
}
#endif

vector< vector<bool> > field;
vector< vector< pair<int, int> > > T1, T2;

template<typename T1, typename T2> int bsrch(vector< pair<T1, T2> > v, T1 val) {
  int l = 0, r = v.size() - 1;
  while (l + 1 < r) {
    int m = (l + r) >> 1;
    if (v[m].first <= val) l = m;
    else r = m;
  }
  if (val < v[l].first) return -1;
  if (val < v[r].first) return l;
  return r;
}

#define getC1(x, y) ((x) + (y))
int count1(int c, int x1, int x2) {
  int a = bsrch(T1[c], x1), b = bsrch(T1[c], x2);
  int cnt = b - a;
  if ((a >= 0) && (T1[c][a].first == x1)) cnt++;
  /*int res = 0;
  for (int i = 0; i < T1[c].size(); i++)
    if ((x1 <= T1[c][i].first) && (T1[c][i].first <= x2))
      res += 1;*/
  return cnt;
}
#define getC2(x, y) ((x) + h - 1 - (y))
int count2(int c, int x1, int x2) {
/*  int res = 0;
  for (int i = 0; i < T2[c].size(); i++)
    if ((x1 <= T2[c][i].first) && (T2[c][i].first <= x2))
      res += 1;*/
  int a = bsrch(T2[c], x1), b = bsrch(T2[c], x2);
  int cnt = b - a;
  if ((a >= 0) && (T2[c][a].first == x1)) cnt++;
  return cnt;
}

int main() {
  {
    FILE *f = fopen("/dev/urandom", "rb");
    if (f) {
      int x;
      fread(&x, sizeof(x), 1, f);
      srand(x);
      fclose(f);
    }
  }
#ifdef DEBUG
  freopen("input.txt", "r", stdin);
  freopen("output.txt", "w", stdout);
#endif

  int w, h;
#ifdef DEBUG
  while (scanf("%d", &h) != EOF) {
#else
    scanf("%d", &h);
#endif
    scanf("%d\n", &w);
    field = vector< vector<bool> >(h, vector<bool>(w));

    for (int y = 0; y < h; y++) {
      string s;
      getline(cin, s);
      for (int x = 0; x < w; x++) field[y][x] = (s[x] == '*');
    }
    
    int bn = 0, bcx = 0, bcy = 0, br = 0;
    
    T1 = vector< vector< pair<int, int> > >(w + h - 1);
    T2 = vector< vector< pair<int, int> > >(w + h - 1);
    for (int y = 0; y < h; y++)
      for (int x = 0; x < w; x++)
        if (field[y][x]) {
          T1[getC1(x, y)].push_back(make_pair(x, y));
          T2[getC2(x, y)].push_back(make_pair(x, y));
        }
    for (int i = 0; i < T1.size(); i++) sort(T1[i].begin(), T1[i].end());
    for (int i = 0; i < T2.size(); i++) sort(T2[i].begin(), T2[i].end());
    
    for (int y = 0; y < h; y++) {
      int curn = !!field[y][0], r = 0;
      for (int x = 0; x < w; x++) {
        #ifdef DEBUG
        eprintf("%d %d %d\n", x, y, r);
        #endif
        if (bn < curn) { bn = curn; bcx = x; bcy = y; br = r; }
        if (x + 1 >= w) break;
        
        enum Act { move = 0, up = 1, down = -1 } act;
        int ax, ay, diff;
        
        if (x + r + 1 < w) {
          if (r) {
            bool good = true;
            ax = x + 1, ay = y - r;
            good = good && !(field[ay][ax] && field[ay + 1][ax]); ay++, ax++;
            for (; ay < y; ay++, ax++) {
              good = good && !(field[ay][ax] && field[ay][ax - 1]);
              good = good && !(field[ay][ax] && field[ay + 1][ax]);
            }
            good = good && !(field[ay][ax] && field[ay][ax - 1]); ay++, ax--;
            for (; ax > x + 1; ay++, ax--) {
              good = good && !(field[ay][ax] && field[ay][ax - 1]);
              good = good && !(field[ay][ax] && field[ay - 1][ax]);
            }
            good = good && !(field[ay][ax] && field[ay - 1][ax]);
          
            if (good) { // We can move our romb :)
              good = false;
              if ((y - r - 1 >= 0) && (y + r + 1 < h) &&
                  (x + r + 2 < w)) {
                good = true;
                ax = x + 1, ay = y - r - 1;
                good = good && !(field[ay][ax] && field[ay + 1][ax]); ay++, ax++;
                for (; ay < y; ay++, ax++) {
                  good = good && !(field[ay][ax] && field[ay][ax - 1]);
                  good = good && !(field[ay][ax] && field[ay - 1][ax]);
                }
                good = good && !(field[ay][ax] && field[ay][ax - 1]); ay++, ax--;
                for (; ax > x + 1; ay++, ax--) {
                  good = good && !(field[ay][ax] && field[ay][ax - 1]);
                  good = good && !(field[ay][ax] && field[ay - 1][ax]);
                }
                good = good && !(field[ay][ax] && field[ay - 1][ax]);
              }
              act = good ? up : move;
            } else
              act = down;
	  } else {
	    if ((y - 1 >= 0) && (y + 1 < h) &&
	        (x + 2 < w) &&
	        !(field[y][x + 1] && field[y][x]) &&
	        !(field[y][x + 1] && field[y - 1][x + 1]) &&
	        !(field[y][x + 1] && field[y][x + 2]) &&
	        !(field[y][x + 1] && field[y + 1][x + 1]) ) act = up;
	    else act = move;
	  }
        } else act = down;
        #ifdef DEBUG
        eprintf(" @%d\n", act);
        #endif
        if (act != up) { // Type 1
          #ifdef DEBUG
          ax = x, ay = y - r; diff = 0;
          for (; ay < y; ay++, ax--)  diff -= !!field[ay][ax];
          for (; ax <= x; ay++, ax++) diff -= !!field[ay][ax];
          assert(-diff == (
            count1(getC1(x, y - r), x - r + 1, x) +
            count2(getC2(x, y + r), x - r, x)
            ));
          curn += diff;
          #else
          curn -=
            count1(getC1(x, y - r), x - r + 1, x) +
            count2(getC2(x, y + r), x - r, x);
          #endif
        }
        if (act == down) { // Type 2
          #ifdef DEBUG
          ax = x, ay = y - r + 1; diff = 0;
          for (; ay < y; ay++, ax--)  diff -= !!field[ay][ax];
          for (; ax <= x; ay++, ax++) diff -= !!field[ay][ax];
          assert(-diff == (
            count1(getC1(x, y - r + 1), x - r + 2, x) +
            count2(getC2(x, y + r - 1), x - r + 1, x)
            ));
          curn += diff;
          #else
          curn -= 
            count1(getC1(x, y - r + 1), x - r + 2, x) +
            count2(getC2(x, y + r - 1), x - r + 1, x);
          #endif
        }
        if (act != down) { // Type 3
          #ifdef DEBUG
          ax = x + 1, ay = y - r; diff = 0;
          for (; ay < y; ay++, ax++)  diff += !!field[ay][ax];
          for (; ax >= x + 1; ay++, ax--) diff += !!field[ay][ax];
          assert(diff == (
            count2(getC2(x + 1, y - r), x + 1, x + r) +
            count1(getC1(x + 1, y + r), x + 1, x + r + 1)
            ));
          curn += diff;
          #else
          curn +=
            count2(getC2(x + 1, y - r), x + 1, x + r) +
            count1(getC1(x + 1, y + r), x + 1, x + r + 1);
          #endif
        }
        if (act == up) { // Type 4
          #ifdef DEBUG
          ax = x + 1, ay = y - r - 1; diff = 0;
          for (; ay < y; ay++, ax++)  diff += !!field[ay][ax];
          for (; ax >= x + 1; ay++, ax--) diff += !!field[ay][ax];
          assert(diff == (
            count2(getC2(x + 1, y - r - 1), x + 1, x + r + 1) +
            count1(getC1(x + 1, y + r + 1), x + 1, x + r + 2)
            ));
          curn += diff;
          #else
          curn +=
            count2(getC2(x + 1, y - r - 1), x + 1, x + r + 1) +
            count1(getC1(x + 1, y + r + 1), x + 1, x + r + 2);
          #endif
        }
        r += act;
      }
    }
    
    printf("%d %d %d %d\n", bn, bcx + 1, bcy + 1, br);
#ifdef DEBUG
  }
#endif

  return 0;
}
