#include <cstdio>
#include <cstdlib>
#include <algorithm>
#include <vector>
#include <list>
#include <string>
#include <assert.h>
#include <iostream>

using namespace std;

#ifdef DEBUG
int eprintf(const char* format, ...) {
  va_list args;
  va_start(args, format);
  int ret = vfprintf(stderr, format, args);
  va_end(args);
  return ret;
}
#endif

int dx[] = {0, 0, -1};
int dy[] = {-1, 1, 0};

//vector< vector<bool> > field;
bool field[3000][3000];
vector< vector<int> > T1, T2;
vector< vector<int> > bad1[3], bad2[3];

inline int bsrch(vector<int> &v, int val) {
  if (!v.size()) return -1;
  if (val < v[0]) return -1;
  if (v[v.size() - 1] <= val) return v.size() - 1;
  
  int l = 0, r = v.size();
  while (l + 1 < r) {
    int m = (l + r) >> 1;
    if (v[m] <= val) l = m;
    else r = m;
  }
  #if DEBUG
  for (int i = 0; i < v.size(); i++)
    if (val < v[i]) { assert(l == i - 1); return i - 1; }
  assert(l == v.size() - 1); return v.size() - 1;
  #else
  return l;
  #endif
}

#define getC1(x, y) ((x) + (y))
#define getC2(x, y) ((x) + h - 1 - (y))
inline int count1(int c, int x1, int x2) {
  if (x1 > x2) return 0;
  
  int a = bsrch(T1[c], x1), b = bsrch(T1[c], x2);
  int cnt = b - a;
  if ((a >= 0) && (T1[c][a] == x1)) cnt++;
  return cnt;
}
inline int count2(int c, int x1, int x2) {
  if (x1 > x2) return 0;
  int a = bsrch(T2[c], x1), b = bsrch(T2[c], x2);
  int cnt = b - a;
  if ((a >= 0) && (T2[c][a] == x1)) cnt++;
  return cnt;
}

inline int count1b(int c, int dir, int x1, int x2) {
  if (x1 > x2) return 0;
  if (dir > 1) dir--;
  int a = bsrch(bad1[dir][c], x1), b = bsrch(bad1[dir][c], x2);
  int cnt = b - a;
    if ((a >= 0) && (bad1[dir][c][a] == x1)) cnt++;
  return cnt;
}
inline int count2b(int c, int dir, int x1, int x2) {
  if (x1 > x2) return 0;
  if (dir > 1) dir--;
  int a = bsrch(bad2[dir][c], x1), b = bsrch(bad2[dir][c], x2);
  int cnt = b - a;
  if ((a >= 0) && (bad2[dir][c][a] == x1)) cnt++;
  return cnt;
}

int main() {
  {
    FILE *f = fopen("/dev/urandom", "rb");
    if (f) {
      int x;
      fread(&x, sizeof(x), 1, f);
      srand(x);
      fclose(f);
    }
  }
#ifdef DEBUG
  freopen("input.txt", "r", stdin);
  freopen("output.txt", "w", stdout);
#endif

  int w, h;
#ifdef DEBUG
  while (scanf("%d", &h) != EOF) {
#else
    scanf("%d", &h);
#endif
    scanf("%d\n", &w);
    //field = vector< vector<bool> >(h, vector<bool>(w));

    for (int y = 0; y < h; y++) {
      string s;
      getline(cin, s);
      for (int x = 0; x < w; x++) field[y][x] = (s[x] == '*');
    }
    
    int bn = 0, bcx = 0, bcy = 0, br = 0;
    
    T1 = vector< vector<int> >(w + h - 1);
    T2 = vector< vector<int> >(w + h - 1);
    for (int y = 0; y < h; y++)
      for (int x = 0; x < w; x++)
        if (field[y][x]) T2[getC2(x, y)].push_back(x);
    for (int y = h - 1; y >= 0; y--)
      for (int x = 0; x < w; x++)
        if (field[y][x]) T1[getC1(x, y)].push_back(x);
    //for (int i = 0; i < T1.size(); i++) sort(T1[i].begin(), T1[i].end());
    //for (int i = 0; i < T2.size(); i++) sort(T2[i].begin(), T2[i].end());
    
    for (int dir = 0; dir < 3; dir++) {
      bad1[dir] = vector< vector<int> >(w + h + 1);
      bad2[dir] = vector< vector<int> >(w + h + 1);
      for (int y = 0; y < h; y++) {
        if ((y + dy[dir] < 0) || (y + dy[dir] >= h)) continue;
        for (int x = 0; x < w; x++) {
          if ((x + dx[dir] < 0) || (x + dx[dir] >= w)) continue;
          if (field[y][x] && field[y + dy[dir]][x + dx[dir]])
            bad2[dir][getC2(x, y)].push_back(x);
        }
      }
      for (int y = h - 1; y >= 0; y--) {
        if ((y + dy[dir] < 0) || (y + dy[dir] >= h)) continue;
        for (int x = 0; x < w; x++) {
          if ((x + dx[dir] < 0) || (x + dx[dir] >= w)) continue;
          if (field[y][x] && field[y + dy[dir]][x + dx[dir]])
            bad1[dir][getC1(x, y)].push_back(x);
        }
      }
/*      for (int i = 0; i < bad1[dir].size(); i++)
        sort(bad1[dir][i].begin(), bad1[dir][i].end());
      for (int i = 0; i < bad2[dir].size(); i++)
        sort(bad2[dir][i].begin(), bad2[dir][i].end());*/
    }
    fprintf(stderr, "Pre-calc finished\n");
    
    for (int y = 0; y < h; y++) {
      int curn = !!field[y][0], r = 0;
      for (int x = 0; x < w; x++) {
        #ifdef DEBUG
        //eprintf("%d %d %d\n", x, y, r);
        #endif
        if (bn < curn) { bn = curn; bcx = x; bcy = y; br = r; }
        if (x + 1 >= w) break;
        
        enum Act { move = 0, up = 1, down = -1 } act;
        int ax, ay, diff;
        
        if (x + r + 1 < w) {
          if (r) {
            #ifdef DEBUG
            bool good = true; // Check type 3
            ax = x + 1, ay = y - r;
            good = good && !(field[ay][ax] && field[ay + 1][ax]); ay++, ax++;
            for (; ay < y; ay++, ax++) {
              good = good && !(field[ay][ax] && field[ay][ax - 1]);
              good = good && !(field[ay][ax] && field[ay + 1][ax]);
            }
            good = good && !(field[ay][ax] && field[ay][ax - 1]); ay++, ax--;
            for (; ax > x + 1; ay++, ax--) {
              good = good && !(field[ay][ax] && field[ay][ax - 1]);
              good = good && !(field[ay][ax] && field[ay - 1][ax]);
            }
            good = good && !(field[ay][ax] && field[ay - 1][ax]);
            #endif
            
            bool good2 = true;
            good2 = good2 && !count2b(getC2(x + 1, y - r), 2, x + 1, x + r);
            good2 = good2 && !count2b(getC2(x + 1, y - r), 3, x + 2, x + r + 1);
            good2 = good2 && !count1b(getC1(x + 1, y + r), 0, x + 1, x + r);
            good2 = good2 && !count1b(getC1(x + 1, y + r), 3, x + 2, x + r + 1);
            #ifdef DEBUG
            assert(good == good2);
            #else
            bool good = good2;
            #endif
          
            if (good) { // We can move our romb :)
              good = false;
              if ((y - r - 1 >= 0) && (y + r + 1 < h) &&
                  (x + r + 2 < w)) { // Check type 4
		#ifdef DEBUG
                good = true;
                
                ax = x + 1, ay = y - r - 1;
                good = good && !(field[ay][ax] && field[ay + 1][ax]); ay++, ax++;
                for (; ay < y; ay++, ax++) {
                  good = good && !(field[ay][ax] && field[ay][ax - 1]);
                  good = good && !(field[ay][ax] && field[ay + 1][ax]);
                }
                good = good && !(field[ay][ax] && field[ay][ax - 1]); ay++, ax--;
                for (; ax > x + 1; ay++, ax--) {
                  good = good && !(field[ay][ax] && field[ay][ax - 1]);
                  good = good && !(field[ay][ax] && field[ay - 1][ax]);
                }
                good = good && !(field[ay][ax] && field[ay - 1][ax]);
                #endif
                
                good2 = true;
                good2 = good2 && !count2b(getC2(x + 1, y - r - 1), 2, x + 1, x + r + 1);
                good2 = good2 && !count2b(getC2(x + 1, y - r - 1), 3, x + 2, x + r + 2);
                good2 = good2 && !count1b(getC1(x + 1, y + r + 1), 0, x + 1, x + r + 1);
                good2 = good2 && !count1b(getC1(x + 1, y + r + 1), 3, x + 2, x + r + 2);
                #ifdef DEBUG
                assert(good == good2);
                #else
                good = good2;
                #endif
              }
              act = good ? up : move;
            } else
              act = down;
	  } else {
	    if ((y - 1 >= 0) && (y + 1 < h) &&
	        (x + 2 < w) &&
	        !(field[y][x + 1] && field[y][x]) &&
	        !(field[y][x + 1] && field[y - 1][x + 1]) &&
	        !(field[y][x + 1] && field[y][x + 2]) &&
	        !(field[y][x + 1] && field[y + 1][x + 1]) ) act = up;
	    else act = move;
	  }
        } else act = down;
        
        if (act != up) { // Type 1
          #ifdef DEBUG
          ax = x, ay = y - r; diff = 0;
          for (; ay < y; ay++, ax--)  diff -= !!field[ay][ax];
          for (; ax <= x; ay++, ax++) diff -= !!field[ay][ax];
          assert(-diff == (
            count1(getC1(x, y - r), x - r + 1, x) +
            count2(getC2(x, y + r), x - r, x)
            ));
          curn += diff;
          #else
          curn -=
            count1(getC1(x, y - r), x - r + 1, x) +
            count2(getC2(x, y + r), x - r, x);
          #endif
        }
        if (act == down) { // Type 2
          #ifdef DEBUG
          ax = x, ay = y - r + 1; diff = 0;
          for (; ay < y; ay++, ax--)  diff -= !!field[ay][ax];
          for (; ax <= x; ay++, ax++) diff -= !!field[ay][ax];
          assert(-diff == (
            count1(getC1(x, y - r + 1), x - r + 2, x) +
            count2(getC2(x, y + r - 1), x - r + 1, x)
            ));
          curn += diff;
          #else
          curn -= 
            count1(getC1(x, y - r + 1), x - r + 2, x) +
            count2(getC2(x, y + r - 1), x - r + 1, x);
          #endif
        }
        if (act != down) { // Type 3
          #ifdef DEBUG
          ax = x + 1, ay = y - r; diff = 0;
          for (; ay < y; ay++, ax++)  diff += !!field[ay][ax];
          for (; ax >= x + 1; ay++, ax--) diff += !!field[ay][ax];
          assert(diff == (
            count2(getC2(x + 1, y - r), x + 1, x + r) +
            count1(getC1(x + 1, y + r), x + 1, x + r + 1)
            ));
          curn += diff;
          #else
          curn +=
            count2(getC2(x + 1, y - r), x + 1, x + r) +
            count1(getC1(x + 1, y + r), x + 1, x + r + 1);
          #endif
        }
        if (act == up) { // Type 4
          #ifdef DEBUG
          ax = x + 1, ay = y - r - 1; diff = 0;
          for (; ay < y; ay++, ax++)  diff += !!field[ay][ax];
          for (; ax >= x + 1; ay++, ax--) diff += !!field[ay][ax];
          assert(diff == (
            count2(getC2(x + 1, y - r - 1), x + 1, x + r + 1) +
            count1(getC1(x + 1, y + r + 1), x + 1, x + r + 2)
            ));
          curn += diff;
          #else
          curn +=
            count2(getC2(x + 1, y - r - 1), x + 1, x + r + 1) +
            count1(getC1(x + 1, y + r + 1), x + 1, x + r + 2);
          #endif
        }
        r += act;
      }
    }
    
    printf("%d %d %d %d\n", bn, bcx + 1, bcy + 1, br);
#ifdef DEBUG
  }
#endif

  return 0;
}
