#include <cstdio>
#include <cstdlib>
#include <algorithm>
#include <vector>
#include <list>
#include <string>
#include <assert.h>
#include <iostream>
#include <set>
#include <map>

using namespace std;

#ifdef DEBUG
int eoffset = 0;

int eprintf(const char* format, ...) {
  va_list args;
  va_start(args, format);
  int ret = vfprintf(stderr, format, args);
  va_end(args);
  return ret;
}
int eoprintf(const char* format, ...) {
  for (int i = 0; i < eoffset; i++) fprintf(stderr, " ");
  va_list args;
  va_start(args, format);
  int ret = vfprintf(stderr, format, args);
  va_end(args);
  return ret;
}
#endif

struct ver_int {
  int dat;
  map<string, ver_int*> childs;
  
  ver_int() { }
  ver_int(int _dat) { dat = _dat; }
};

struct ver {
  string name;
  int i_change; ver_int *i_int;
  int depth, branch;
  vector<ver*> childs;
  #ifdef DEBUG
  ver* par;
  #endif
  
  ver() {
    #ifdef DEBUG
    par = 0;
    #endif
    depth = -1; branch = 0; i_change = -1; i_int = 0;
  }
};

int n;
struct branch {
  vector<ver*> vers;
  vector< vector<int> > changes;
  
  branch() { changes = vector< vector<int> >(n); }
  void insert(ver *_ver) {
    _ver->depth = vers.size();
    vers.push_back(_ver);
    changes[_ver->i_change].push_back(_ver->depth);
  }
};

vector<ver_int> arr;
ver g_vers;

ver ver_mem[100000]; int ver_mem_pos;
ver_int ver_int_mem[100000]; int ver_int_mem_pos;

#ifdef DEBUG
void dbgprint(ver &v) {
  eoprintf("I am %s\n", v.name.c_str());
  eoffset += 2;
  for (int i = 0; i < v.childs.size(); i++) {
    assert(v.childs[i]);
    assert(v.childs[i]->par == &v);
    dbgprint(*v.childs[i]);
  }
  eoffset -= 2;
}
#endif


inline int bsrch(vector<int> &v, int val) {
  if (!v.size()) return -1;
  if (val < v[0]) return -1;
  if (v[v.size() - 1] <= val) return v.size() - 1;
  
  int l = 0, r = v.size();
  while (l + 1 < r) {
    int m = (l + r) >> 1;
    if (v[m] <= val) l = m;
    else r = m;
  }
  #if DEBUG
  for (int i = 0; i < v.size(); i++)
    if (val < v[i]) { assert(l == i - 1); return i - 1; }
  assert(l == v.size() - 1); return v.size() - 1;
  #else
  return l;
  #endif
}

int main() {
  {
    FILE *f = fopen("/dev/urandom", "rb");
    if (f) {
      int x;
      fread(&x, sizeof(x), 1, f);
      srand(x);
      fclose(f);
    }
  }
#ifdef DEBUG
  freopen("input.txt", "r", stdin);
  freopen("output.txt", "w", stdout);
#endif

#ifdef DEBUG
  while (scanf("%d", &n) != EOF) {
#else
    scanf("%d", &n);
#endif
    arr = vector<ver_int>(n, ver_int(0));
    vector<branch> branches(1);
    
    map<string, ver* > vers;
    
    int k;
    char buf[11]; scanf(" %s %d", buf, &k);
    g_vers = ver();
    g_vers.name = buf;
    vers.insert(make_pair(buf, &g_vers));
    #ifdef DEBUG
    dbgprint(g_vers);
    #endif
    
    ver_mem_pos = 0; ver_int_mem_pos = 0;
    for (int i = 0;  i < k; i++) {
      char com; int field, newval;
      char v1[11]; char v2[11];
      scanf(" %c %s %d", &com, v1, &field); field--;
        
      ver *cver = vers.find(v1)->second;
      ver_int *cvver = 0;
      #ifdef DEBUG
      for (ver *_i = cver; _i; _i = _i->par)
        if (!_i->par) cvver = &arr[field];
        else if (_i->i_change == field) {
          cvver = _i->i_int; break;
        }
      ver_int *__cvver = cvver;
      #endif
      {
        int cb = cver->branch, cd = cver->depth;
        /*int i2 = branches[cb].changes[field].size() - 1;
        for (; i2 >= 0; i2--)
          if (branches[cb].changes[field][i2] <= cd) break;*/
        int i2 = bsrch(branches[cb].changes[field], cd);
        if (i2 < 0) cvver = &arr[field];
        else cvver = branches[cb].vers[branches[cb].changes[field][i2]]->i_int;
      }
      #ifdef DEBUG
      assert(__cvver == cvver);
      #endif
        
      
      switch (com) {
      case 'S': {
        scanf(" %d %s", &newval, v2);
        ver_int *iver = &ver_int_mem[ver_int_mem_pos++];
        *iver = ver_int(newval);
        cvver->childs.insert(make_pair(v2, iver));
          
        ver *nver = &ver_mem[ver_mem_pos++];
        *nver = ver();
        nver->name = v2;
        #ifdef DEBUG
        nver->par = cver;
        #endif
        nver->i_change = field; nver->i_int = iver;
        
        if (cver->childs.size()) {
          branches.resize(branches.size() + 1);
          nver->branch = branches.size() - 1;
        } else
          nver->branch = cver->branch;
        branches[nver->branch].insert(nver);
        
        cver->childs.push_back(nver);
        vers.insert(make_pair(v2, cver->childs[cver->childs.size() - 1]));
        #ifdef DEBUG
        dbgprint(g_vers);
        #endif
        } break;
      case 'G':
        printf("%d\n", cvver->dat); fflush(stdout);
        break;
      }
    }
    
    
#ifdef DEBUG
  }
#endif
  return 0;
}
