#include <cstdio>
#include <cstdlib>
#include <algorithm>
#include <vector>
#include <list>
#include <string>
#include <assert.h>
#include <iostream>

using namespace std;

#ifdef DEBUG
int eoffset = 0;

int eprintf(const char* format, ...) {
  va_list args;
  va_start(args, format);
  int ret = vfprintf(stderr, format, args);
  va_end(args);
  return ret;
}
int eoprintf(const char* format, ...) {
  for (int i = 0; i < eoffset; i++) fprintf(stderr, " ");
  va_list args;
  va_start(args, format);
  int ret = vfprintf(stderr, format, args);
  va_end(args);
  return ret;
}
#endif

#define PLAYERS 4
#define CARDS 36

typedef int Card;
int trump;
int ctypes[1 << (8 * sizeof(char))];
char dectypes[4];

char buf[3];
Card parse_card(char *card) {
  Card res;
  if ((card[0] >= '6') && (card[0] <= '9')) res = card[0] - '6';
  else if (card[0] == 'T') res = 4;
  else if (card[0] == 'J') res = 5;
  else if (card[0] == 'Q') res = 6;
  else if (card[0] == 'K') res = 7;
  else if (card[0] == 'A') res = 8;
  else assert(false);
  res <<= 2; res += ctypes[card[1]];
  return res;
}
char* deparse_card(Card card) {
  buf[1] = dectypes[card & 3]; card >>= 2;
  if ((card >= 0) && (card <= 3)) buf[0] = card + '6';
  else if (card == 4) buf[0] = 'T';
  else if (card == 5) buf[0] = 'J';
  else if (card == 6) buf[0] = 'Q';
  else if (card == 7) buf[0] = 'K';
  else if (card == 8) buf[0] = 'A';
  else assert(false);
  buf[2] = 0;
  return buf;
}
enum CmpResult { LESS, EQ, BIG, NOT_COMPARABLE };
CmpResult cmp(Card a, Card b) {
  if ((a & 3) == (b & 3)) {
    if ((a >> 2) < (b >> 2)) return LESS;
    if ((a >> 2) == (b >> 2)) return EQ;
    return BIG;
  }
  if ((a & 3) == trump) return BIG;
  if ((b & 3) == trump) return LESS;
  return NOT_COMPARABLE;
}

enum CardState { NOT_HAVE = -1, UNKNOWN = 0, HAVE = 1 };
int ccount[PLAYERS];
CardState cstate[PLAYERS][CARDS];
bool was_value[9];
int turn_b;
vector<Card> cur_cards; bool taked;
int remains;

int outed[PLAYERS];

void normalize(int &id) {
  if (outed[id]) id = (id + 2) & 3;
}

int main() {
  {
    FILE *f = fopen("/dev/urandom", "rb");
    if (f) {
      int x;
      fread(&x, sizeof(x), 1, f);
      srand(x);
      fclose(f);
    }
  }
/*#ifdef DEBUG
  freopen("input.txt", "r", stdin);
  freopen("output.txt", "w", stdout);
#endif*/

  memset(ccount, 0, sizeof ccount);
  memset(cstate, 0, sizeof cstate);
  memset(outed, 0, sizeof outed);
  dectypes[0] = 'H';
  dectypes[1] = 'S';
  dectypes[2] = 'C';
  dectypes[3] = 'D';
  for (int i = 0; i < 4; i++)
    ctypes[dectypes[i]] = i;
  remains = 36;
  
  int prev_i = 0; bool first_double_circle = true;
  for (;;) {
    char command[6];
    char _card[3]; Card card;
    int i1, i2;
    
    scanf(" %s", command);
    if (!strcmp(command, "trump")) {
      scanf(" %c", &trump);
      trump = ctypes[trump];
    } else if (!strcmp(command, "give")) {
      scanf(" %d %s", &i1, _card), i1--; normalize(i1);
      ccount[i1]++;
      remains--;
      
      if (strcmp(_card, "??")) {
        card = parse_card(_card);
        cstate[i1][card] = HAVE;
        for (int i = 0; i < PLAYERS; i++)
          if (i != i1) cstate[i][card] = NOT_HAVE;
      }
    } else if (!strcmp(command, "move")) {
      scanf(" %d %d %s", &i1, &i2, _card), i1--, i2--;
      normalize(i1); normalize(i2);
      ccount[i1]--;
      card = parse_card(_card);
      
      turn_b = i2;
      cur_cards = vector<int>(1, card);
      
      memset(was_value, 0, sizeof was_value);
      was_value[card >> 2] = true;
      for (int i = 0; i < PLAYERS; i++)
        cstate[i][card] = NOT_HAVE;
      taked = false;
    } else if (!strcmp(command, "add")) {
      scanf(" %d %d %s", &i1, &i2, _card), i1--, i2--;
      normalize(i1); normalize(i2);
      assert(i2 == turn_b);
      ccount[i1]--;
      card = parse_card(_card);
      
      cur_cards.push_back(card);
      was_value[card >> 2] = true;
      for (int i = 0; i < PLAYERS; i++)
        cstate[i][card] = NOT_HAVE;
    } else if (!strcmp(command, "beat")) {
      scanf(" %d %s", &i2, _card), i2--;
      normalize(i2);
      assert(i2 == turn_b);
      ccount[i2]--;
      card = parse_card(_card);
      
      cur_cards.push_back(card);
      for (int i = 0; i < PLAYERS; i++)
        cstate[i][card] = NOT_HAVE;
    } else if (!strcmp(command, "take")) {
      scanf(" %d", &i2), i2--;
      normalize(i2);
      assert(i2 == turn_b);
      
      ccount[i2] += cur_cards.size();
      for (int i = 0; i < cur_cards.size(); i++)
        cstate[i2][cur_cards[i]] = HAVE;
      taked = true;
    } else if (!strcmp(command, "out")) {
      scanf(" %d", &i2), i2--;
      normalize(i2);
      outed[i2] = true;
    } else if (!strcmp(command, "MOVE")) {
      i1 = prev_i;
      if (PLAYERS == 4)
        if (outed[2]) {
          if (!first_double_circle) i1 = (i1 + 2) & 3;
          first_double_circle = true;
        }
      prev_i = i1;
      
      i2 = i1 + 1;
      while (outed[i2] || (i2 == 0) || (i2 == 2)) i2 = (i2 + 1) & 3;
      
      Card mcard = -1;
      for (int i = 0; i < CARDS; i++)
        if ((cstate[0][i] == HAVE) && ((mcard == -1) || (cmp(i, mcard) == LESS)))
          mcard = i;
      printf("%s\n", deparse_card(mcard));
    } else if (!strcmp(command, "BEAT")) {
      Card ccard = cur_cards[cur_cards.size() - 1];
      
      Card mcard = -1;
      for (int i = 0; i < CARDS; i++)
        if ((cstate[0][i] == HAVE) && (cmp(ccard, i) == LESS)) {
          if ((mcard == -1) || (cmp(i, mcard) == LESS))
            mcard = i;
        }
      if (mcard == -1) printf("NO\n");
      else printf("%s\n", deparse_card(mcard));
    } else if (!strcmp(command, "ADD")) {
      i2 = turn_b;
      
      Card mcard = -1;
      if (remains || (ccount[0] > 1)) {
        double p[CARDS];
        for (int a = 0; a < CARDS; a++) {
          p[a] = 0;
          if ((cstate[0][a] == HAVE) && was_value[a >> 2]) {
            int cnt1 = 0, cnt2 = 0;
            for (int b = 0; b < CARDS; b++)
              if (cmp(a, b) == LESS) {
                cnt2 += 3;
                switch (cstate[i2][b]) {
                case UNKNOWN: cnt1++; break;
                case NOT_HAVE: cnt1 += 3; break;
                }
              }
            if ((cnt2 == 0) || taked) p[a] = 1;
            else p[a] = cnt1 / cnt2;
            if ((a & 3) != trump)
              if ((a >> 2) > 6) p[a] *= 1.5;
              else p[a] *= 3;
          }
        }
        double max = p[0]; int maxi = 0;
        for (int a = 0; a < CARDS; a++)
          if (p[a] > max) { max = p[a]; maxi = a; }
        if (max > 0) printf("%s\n", deparse_card(maxi));
        else {
          maxi = -1;
          max = -1;
          for (int a = 0; a < CARDS; a++)
            if ((cstate[0][a] == HAVE) && was_value[a >> 2] &&
                ((a & 3) != trump) && ((a >> 2) <= 5))
                  if (5 - (a >> 2) > max) {
                    max = 5 - (a >> 2);
                    maxi = a;
                  }
          if (maxi >= 0) printf("%s\n", deparse_card(maxi));
          else printf("NO\n");
        }
      } else {
        for (int i = 0; i < CARDS; i++)
          if ((cstate[0][i] == HAVE) && was_value[i >> 2])
            mcard = i;
        if (mcard == -1) printf("NO\n");
        else printf("%s\n", deparse_card(mcard));
      }
    }
    fflush(stdout);
    if (outed[0]) break;
    
    if (PLAYERS == 4) {
      if (outed[1] && outed[3]) break;
    } else {
      if (outed[1]) break;
    }
  }
  return 0;
}
