#include <cstdio>
#include <cstdlib>
#include <algorithm>
#include <vector>
#include <list>
#include <string>
#include <assert.h>
#include <iostream>

using namespace std;

#ifdef DEBUG
int eoffset = 0;

int eprintf(const char* format, ...) {
  va_list args;
  va_start(args, format);
  int ret = vfprintf(stderr, format, args);
  va_end(args);
  return ret;
}
int eoprintf(const char* format, ...) {
  for (int i = 0; i < eoffset; i++) fprintf(stderr, " ");
  va_list args;
  va_start(args, format);
  int ret = vfprintf(stderr, format, args);
  va_end(args);
  return ret;
}
#endif

char bits_count(int mask) {
  char ans = 0;
  for (; mask; mask >>= 1) ans += mask & 1;
  return ans;
}

typedef vector<int> box;

void relax(int &ov, int nv, char &od, char nd) {
  if (ov < nv) ov = nv, od = nd;
}

int n;
box boxes[20];
int can[20][3][20];
int encode[1 << 20];
int ans[2][184756][20][3]; // c[20][10] = 184756
char from[1 << 20][20][3];
vector<int> order[21];

int main() {
  {
    FILE *f = fopen("/dev/urandom", "rb");
    if (f) {
      int x;
      fread(&x, sizeof(x), 1, f);
      srand(x);
      fclose(f);
    }
  }
#ifdef DEBUG
  freopen("input.txt", "r", stdin);
  freopen("output.txt", "w", stdout);
#endif

#ifdef DEBUG
  while (scanf("%d", &n) != EOF) {
#else
    scanf("%d", &n);
#endif
    if (n > 20) return 1;
    for (int i = 0; i < n; i++) {
      boxes[i] = vector<int>(3);
      scanf("%d%d%d", &boxes[i][0], &boxes[i][1], &boxes[i][2]);
    }
    
    for (int a = 0; a < n; a++)
      for (int ta = 0; ta < 3; ta++) {
         vector<int> awh;
         for (int i = 0; i < 3; i++) if (i != ta) awh.push_back(boxes[a][i]);
         
         for (int b = 0; b < n; b++) {
           can[a][ta][b] = 0;
           for (int tb = 0; tb < 3; tb++) {
             vector<int> bwh;
             for (int i = 0; i < 3; i++) if (i != tb) bwh.push_back(boxes[b][i]);
             
             can[a][ta][b] |= (1 << tb) * !!((awh[0] >= bwh[0]) && (awh[1] >= bwh[1]));
             can[a][ta][b] |= (1 << tb) * !!((awh[0] >= bwh[1]) && (awh[1] >= bwh[0]));
           }
         }
      }
      
    for (int i = 0; i < n; i++) order[i] = vector<int>();
    for (int mask = 1; mask < (1 << n); mask++) {
      int bc = bits_count(mask);
      
      order[bc].push_back(mask);
      encode[mask] = order[bc].size() - 1;
    }
    
    int cbid = 0;
    for (int last = 0; last < n; last++)
      for (int lt = 0; lt < 3; lt++) {
        ans[cbid][encode[1 << last]][last][lt] = boxes[last][lt],
        from[1 << last][last][lt] = -1;
      }
    
    int bans = 0, blast = -1, blt = -1;
    for (int mask_bc = 2; mask_bc <= n; mask_bc++) {
      cbid = !cbid;
      for (int mask_id = 0; mask_id < order[mask_bc].size(); mask_id++) {
        int mask = order[mask_bc][mask_id];
        int emask = mask_id;
        for (int last = 0; last < n; last++)
          if (mask & (1 << last)) {
            int nmask = mask ^ (1 << last);
            if (!nmask) continue;
            int enmask = encode[nmask];
            
            ans[cbid][emask][last][0] =
            ans[cbid][emask][last][1] =
            ans[cbid][emask][last][2] = 0;
            for (int pr = 0; pr < n; pr++)
              if (nmask & (1 << pr))
                for (int pt = 0; pt < 3; pt++) {
                  relax(
                    ans[cbid][emask][last][0],
                      (ans[!cbid][enmask][pr][pt] + boxes[last][0]) *
                        !!(can[pr][pt][last] & 1),
                    from[mask][last][0], pr << 2);
                  relax(
                    ans[cbid][emask][last][1],
                      (ans[!cbid][enmask][pr][pt] + boxes[last][1]) *
                        !!(can[pr][pt][last] & 2),
                    from[mask][last][1], (pr << 2) + 1);
                  relax(
                    ans[cbid][emask][last][2],
                      (ans[!cbid][enmask][pr][pt] + boxes[last][2]) *
                        !!(can[pr][pt][last] & 4),
                    from[mask][last][2], (pr << 2) + 2);
                }
            for (int i = 0; i < 3; i++)
              if (bans < ans[cbid][emask][last][i]) {
                bans = ans[cbid][emask][last][i];
                blast = last;
                blt = i;
              }
          }
      }
    }
    
    vector< pair<int, int> > result;
    
    int cmask = (1 << n) - 1, bfrom = from[cmask][blast][blt];
    result.push_back(make_pair(blast, blt));
    while (bfrom >= 0) {
//      eprintf("%d, %d, %d; %d\n", cmask, blast, blt, bfrom);
      cmask ^= (1 << blast);
      blast = bfrom >> 2; blt = bfrom & 3;
      result.push_back(make_pair(blast, blt));
      bfrom = from[cmask][blast][blt];
    }
        
    printf("%d\n", bans);
    for (int i = result.size() - 1; i >= 0; i--) {
      printf("%d", result[i].first + 1);
      for (int i2 = 0; i2 < 3; i2++)
        if (i2 != result[i].second) printf(" %d", boxes[result[i].first][i2]);
      printf(" %d\n", boxes[result[i].first][result[i].second]);
    }
#ifdef DEBUG
  }
#endif

  return 0;
}
