#include <cstdio>
#include <cstdlib>
#include <algorithm>
#include <vector>
#include <list>
#include <string>
#include <assert.h>
#include <iostream>

using namespace std;

#ifdef DEBUG
int eoffset = 0;

int eprintf(const char* format, ...) {
  va_list args;
  va_start(args, format);
  int ret = vfprintf(stderr, format, args);
  va_end(args);
  return ret;
}
int eoprintf(const char* format, ...) {
  for (int i = 0; i < eoffset; i++) fprintf(stderr, " ");
  va_list args;
  va_start(args, format);
  int ret = vfprintf(stderr, format, args);
  va_end(args);
  return ret;
}
#endif

int n;

enum Op { SHIFT, ADD, SUB };
struct Fr {
  Op op;
  int a, b;
};

vector<bool> available, available2;
vector<Fr> operations;

void relax(int &ov, int nv, int &od1, int nd1, int &od2, int nd2) {
  if (ov > nv) {
    ov = nv;
    od1 = nd1;
    od2 = nd2;
  }
}

Fr make_op(Op op, int a, int b) {
  Fr nfr;
  nfr.op = op;
  nfr.a = a;
  nfr.b = b;
  return nfr;
}

vector<int> red;
int make_available(int a, bool print) {
  if (available[a]) return 0;
  if (red[a] == -1) return 1000000000;
  if (!print)
    if (red[a] > 0) return red[a];
  
  red[a] = -1;
  int bans = 2000000000; int bact = -1, bb = 0;
  int ta = a;
  for (int b = 1; !(ta & 1); b++, ta >>= 1)
    relax(bans, make_available(ta >> 1, false) + 1, bact, 0, bb, b);
  for (int b = 1; b < a; b++)
    relax(bans, make_available(a - b, false) + make_available(b, false) + 1,
          bact, 1, bb, b);
  for (int b = 1; a + b <= 42; b++)
    relax(bans, make_available(a + b, false) + make_available(b, false) + 1,
          bact, 2, bb, b);
  if (print) {
    switch (bact) {
      case 0:
        make_available(a >> bb, true);
        operations.push_back(make_op(SHIFT, a >> bb, bb));
        break;
      case 1:
        make_available(a - bb, true);
        make_available(bb, true);
        operations.push_back(make_op(ADD, a - bb, bb));
        break;
      case 2:
        make_available(a + bb, true);
        make_available(bb, true);
        operations.push_back(make_op(SUB, a + bb, bb));
        break;
    }
    available2[a] = true;
  }
  red[a] = bans;
  return bans;
}

int main() {
  {
    FILE *f = fopen("/dev/urandom", "rb");
    if (f) {
      int x;
      fread(&x, sizeof(x), 1, f);
      srand(x);
      fclose(f);
    }
  }
#ifdef DEBUG
  freopen("input.txt", "r", stdin);
  freopen("output.txt", "w", stdout);
#endif

#ifdef DEBUG
  while (scanf("%d", &n) != EOF) {
#else
    scanf("%d", &n);
#endif
    vector<int> a(n);
    for (int i = 0; i < n; i++) scanf("%d", &a[i]);
    sort(a.begin(), a.end());
    
    operations = vector<Fr>();
    available = vector<bool>(43, false);
    available[1] = true;
    for (int i = 0; i < n; i++) {
      red = vector<int>(43, 0);
      available2 = vector<bool>(43, false);
      make_available(a[i], true);
      for (int i2 = 1; i2 <= 42; i2++)
        available[i2] = available[i2] || available2[i2];
    }
    
    printf("%d\n", operations.size());
    for (int i = 0; i < operations.size(); i++)
      switch (operations[i].op) {
        case SHIFT: printf("%d<<%d\n", operations[i].a, operations[i].b); break;
        case ADD: printf("%d+%d\n", operations[i].a, operations[i].b); break;
        case SUB: printf("%d-%d\n", operations[i].a, operations[i].b); break;
      }
#ifdef DEBUG
  }
#endif

  return 0;
}
