#include <cstdio>
#include <cstdlib>
#include <algorithm>
#include <vector>
#include <list>
#include <string>
#include <assert.h>
#include <iostream>
#include <queue>

using namespace std;

#ifdef DEBUG
int eoffset = 0;

int eprintf(const char* format, ...) {
  va_list args;
  va_start(args, format);
  int ret = vfprintf(stderr, format, args);
  va_end(args);
  return ret;
}
int eoprintf(const char* format, ...) {
  for (int i = 0; i < eoffset; i++) fprintf(stderr, " ");
  va_list args;
  va_start(args, format);
  int ret = vfprintf(stderr, format, args);
  va_end(args);
  return ret;
}
#endif

struct graph {
  int n, m;
  vector< vector<int> > es, reves;
  
  vector<bool> win;
  vector<int> minW1, maxL1;
};

void calc(graph &g) {
  int n = g.n, m = g.m;

  g.minW1 = vector<int>(n, 2000000000);
  g.maxL1 = vector<int>(n, -1);
  
  vector<int> win(n, 0);
  queue<int> q;
  for (int i = 0; i < n; i++)
    if (!g.es[i].size()) {
      win[i] = 2;
      g.minW1[i] = -1; g.maxL1[i] = 0;
      q.push(i);
    }
  
  for (; !q.empty(); q.pop()) {
    int a = q.front();
    int cw = win[a];
    for (int i = 0; i < g.reves[a].size(); i++) {
      int b = g.reves[a][i];
      if (!win[b]) q.push(b);
      if (cw == 2) {
        win[b] = 1;
        g.minW1[b] = min(g.minW1[b], g.maxL1[a] + 1);
      } else
        if (win[b] != 1)
          win[b] = 2, g.maxL1[b] = max(g.maxL1[b], g.minW1[a] + 1);
    }
  }
  
  g.win = vector<bool>(n);
  for (int i = 0; i < n; i++)
    assert(win[i]), g.win[i] = !(win[i] - 1);
}

graph g1, g2;

int main() {
  {
    FILE *f = fopen("/dev/urandom", "rb");
    if (f) {
      int x;
      fread(&x, sizeof(x), 1, f);
      srand(x);
      fclose(f);
    }
  }
#ifdef DEBUG
  freopen("input.txt", "r", stdin);
  freopen("output.txt", "w", stdout);
#endif

#ifdef DEBUG
  while (scanf("%d", &g1.n) != EOF) {
#else
    scanf("%d", &g1.n);
#endif
    scanf("%d", &g1.m);
    g1.es = vector< vector<int> >(g1.n);
    g1.reves = vector< vector<int> >(g1.n);
    for (int i = 0; i < g1.m; i++) {
      int a, b; scanf("%d%d", &a, &b), a--, b--;
      g1.es[a].push_back(b);
      g1.reves[b].push_back(a);
    }
    
    scanf("%d%d", &g2.n, &g2.m);
    g2.es = vector< vector<int> >(g2.n);
    g2.reves = vector< vector<int> >(g2.n);
    for (int i = 0; i < g2.m; i++) {
      int a, b; scanf("%d%d", &a, &b), a--, b--;
      g2.es[a].push_back(b);
      g2.reves[b].push_back(a);
    }
    
    calc(g1);
    calc(g2);
    #ifdef DEBUG
    eprintf("GRAPH 1:\n");
    for (int i = 0; i < g1.n; i++)
      eprintf("  %d: %d (%d)\n", i + 1, !!g1.win[i],
        g1.win[i] ? g1.minW1[i] : g1.maxL1[i]);
    eprintf("\n");
    
    eprintf("GRAPH 2:\n");
    for (int i = 0; i < g2.n; i++)
      eprintf("  %d: %d (%d)\n", i + 1, !!g2.win[i],
        g2.win[i] ? g2.minW1[i] : g2.maxL1[i]);
    eprintf("\n");
    #endif
    
    int K;
    scanf("%d", &K);
    while (K--) {
      int st1, st2;
      scanf("%d%d", &st1, &st2), st1--, st2--;
      
      int win = 0;
      if (g1.win[st1] && g2.win[st2]) win = 1; // ++
      else if (!g1.win[st1] && !g2.win[st2]) win = 2; //--
      else {
        if (g1.win[st1]) { // +-
          if (g1.minW1[st1] <= g2.maxL1[st2]) win = 1;
          else win = 2;
        } else { // -+
          if (g2.minW1[st2] <= g1.maxL1[st1]) win = 1;
          else win = 2;
        }
      }
      switch (win) {
      case 1: printf("first\n"); break;
      case 2: printf("second\n"); break;
      default: printf("first or second\n"); break;
      }
    }
#ifdef DEBUG
  }
#endif

  return 0;
}
