#include <cstdio>
#include <cstdlib>
#include <algorithm>
#include <vector>
#include <list>
#include <string>
#include <assert.h>
#include <iostream>
#include <math.h>

using namespace std;

#ifdef DEBUG
int eoffset = 0;

int eprintf(const char* format, ...) {
  va_list args;
  va_start(args, format);
  int ret = vfprintf(stderr, format, args);
  va_end(args);
  return ret;
}
int eoprintf(const char* format, ...) {
  for (int i = 0; i < eoffset; i++) fprintf(stderr, " ");
  va_list args;
  va_start(args, format);
  int ret = vfprintf(stderr, format, args);
  va_end(args);
  return ret;
}
#endif

struct point {
  int x, y;
  #ifdef DEBUG
  void print() { eprintf("(%d,%d)", x, y); }
  #endif
};
point make_point(int x, int y) {
  point res;
  res.x = x; res.y = y;
  return res;
}

bool check_crossh(int x1, int y1, int x2, int y2, double ax1, double ax2, int ay) {
  if ((y1 <= ay) && (y2 <= ay)) return false;
  if ((y1 >= ay) && (y2 >= ay)) return false;
  if (y1 == y2) return false;
  if (y1 > y2) {
    int tmp = y1; y1 = y2; y2 = tmp;
    tmp = x1; x1 = x2; x2 = tmp;
  }
  double cx = (double)(x2 - x1) / (double)(y2 - y1) * (double)(ay - y1) + x1;
  if ((ax1 <= cx) && (cx <= ax2)) return true;
  if ((ax2 <= cx) && (cx <= ax1)) return true;
  return false;
}
bool check_crossv(int x1, int y1, int x2, int y2, int ax, double ay1, double ay2) {
  return check_crossh(y1, x1, y2, x2, ay1, ay2, ax);
}

int n;
vector<point> ps1, ps2;

bool is_in(int x, int y, int i) {
  bool crx = false, cry = false;
  crx = crx || ((ps1[i].x <= x) && (x <= ps2[i].x));
  crx = crx || ((ps2[i].x <= x) && (x <= ps1[i].x));
  cry = cry || ((ps1[i].y <= y) && (y <= ps2[i].y));
  cry = cry || ((ps2[i].y <= y) && (y <= ps1[i].y));
  return crx && cry;
}

#define big_condition() ((x1 == 2) && (y1 == 2) && (x2 == 2) && (y2 == 5))
bool check_cross(int x1, int y1, int x2, int y2) {
  for (int i = 0; i < n; i++) {
    if (check_crossh(x1, y1, x2, y2, ps1[i].x, ps2[i].x, ps1[i].y)) return true;
    if (check_crossh(x1, y1, x2, y2, ps1[i].x, ps2[i].x, ps2[i].y)) return true;
    
    if (check_crossv(x1, y1, x2, y2, ps1[i].x, ps1[i].y, ps2[i].y)) return true;
    if (check_crossv(x1, y1, x2, y2, ps2[i].x, ps1[i].y, ps2[i].y)) return true;
  }
  for (int i = 0; i < n; i++)
    if (is_in(x1, y1, i) && is_in(x2, y2, i)) {
      bool bad = true;
      if (x1 == x2) {
        if ((x1 <= ps1[i].x) && (x1 <= ps2[i].x)) bad = false;
        if ((x1 >= ps1[i].x) && (x1 >= ps2[i].x)) bad = false;
      }
      if (y1 == y2) {
        if ((y1 <= ps1[i].y) && (y1 <= ps2[i].y)) bad = false;
        if ((y1 >= ps1[i].y) && (y1 >= ps2[i].y)) bad = false;
      }
      if (bad) return true;
    }
  return false;
}

vector<point> ps;
vector< pair<int, double> > g[4002];


#define dist(x1, y1, x2, y2) sqrt((x2 - x1) * (x2 - x1) + (y2 - y1) * (y2 - y1))
void calc_graph() {
  for (int i = 0; i < ps.size(); i++)
    g[i] = vector< pair<int, double> >();
  
  for (int a = 0; a < ps.size(); a++)
    for (int b = 0; b < ps.size(); b++)
      if (!check_cross(ps[a].x, ps[a].y, ps[b].x, ps[b].y))
        g[a].push_back(make_pair(b, dist(ps[a].x, ps[a].y, ps[b].x, ps[b].y)));
}

void relax(double &ov, double nv, int &od, int nd) {
  if (ov > nv) {
    ov = nv;
    od = nd;
  }
}

vector<double> d;
vector<int> from;
void dijkstra(int st) {
  d = vector<double>(ps.size(), INFINITY);
  from = vector<int>(ps.size(), -1);
  
  vector<bool> red(ps.size(), false);
  
  d[st] = 0;
  for (;;) {
    double mind = INFINITY; int mini = -1;
    for (int i = 0; i < ps.size(); i++)
      if (!red[i] && (d[i] < mind)) { mind = d[i]; mini = i; }
    if (mini < 0) break;
    red[mini] = true;
    
    for (int i = 0; i < g[mini].size(); i++)
      relax(d[g[mini][i].first], mind + g[mini][i].second,
            from[g[mini][i].first], mini);
  }
}

int main() {
  {
    FILE *f = fopen("/dev/urandom", "rb");
    if (f) {
      int x;
      fread(&x, sizeof(x), 1, f);
      srand(x);
      fclose(f);
    }
  }
#ifdef DEBUG
  freopen("input.txt", "r", stdin);
  freopen("output.txt", "w", stdout);
#endif

  point st, en;
#ifdef DEBUG
  while (scanf("%d", &st.x) != EOF) {
#else
    scanf("%d", &st.x);
#endif
    scanf("%d%d%d%d", &st.y, &en.x, &en.y, &n);
    
    ps1 = vector<point>(n);
    ps2 = vector<point>(n);
    for (int i = 0; i < n; i++)
      scanf("%d%d%d%d", &ps1[i].x, &ps1[i].y, &ps2[i].x, &ps2[i].y);
      
    ps = vector<point>((n << 2) + 2);
    for (int i = 0; i < n; i++) {
      ps[i << 2] = ps1[i];
      ps[(i << 2) + 1] = make_point(ps2[i].x, ps1[i].y);
      ps[(i << 2) + 2] = ps2[i];
      ps[(i << 2) + 3] = make_point(ps1[i].x, ps2[i].y);
    }
    ps[n << 2] = st;
    ps[(n << 2) + 1] = en;
    
    calc_graph();
    #ifdef DEBUG
    for (int a = 0; a < ps.size(); a++)
      for (int b = 0; b < g[a].size(); b++) {
        ps[a].print(); eprintf("-");
        ps[g[a][b].first].print(); eprintf(": %.2lf\n", g[a][b].second);
      }
    #endif
    dijkstra(n << 2);
    
    printf("%.7lf\n", d[(n << 2) + 1]);
    vector<point> path;
    for (int cur = (n << 2) + 1; cur >= 0; cur = from[cur])
      path.push_back(ps[cur]);
    
    printf("%d\n", path.size());
    for (int i = path.size() - 1; i >= 0; i--)
      printf("%d %d\n", path[i].x, path[i].y);
#ifdef DEBUG
  }
#endif

  return 0;
}
