#include <stdio.h>
#include <string.h>

#define MMAX 10010
#define NMAX 1010
#define QMAX 10000100
#define WHITE '0'
#define BLACK '1'

typedef struct {
	short int row, col;
} qelem;

#define WMOVES 8
int dwrow[WMOVES] = { -1, -1, 0, +1, +1, +1, 0, -1 };
int dwcol[WMOVES] = { 0, +1, +1, +1, 0, -1, -1, -1 };

#define BMOVES 4
int dbrow[BMOVES] = { -1, 0, +1, 0 };
int dbcol[BMOVES] = { 0, +1, 0, -1 };

qelem Q[QMAX];
char b[MMAX][NMAX], line[NMAX * 2];
short int depth[MMAX][NMAX];
int i, j, ii, jj, k, M, N, li, ls, wfound;
int ntotal, ncomp, maxsz, maxszcomp, maxd;

void compute_depths(void)
{
	// initialize the 'depth' of each cell
	memset(depth, 0, sizeof(depth));

	li = ls = 0;
	for (j = 0; j < N; j++)
	{
		if (b[0][j] == WHITE)
		{
			Q[ls].row = 0;
			Q[ls].col = j;
			ls = (ls + 1) % QMAX;
			depth[0][j] = 1;
		}

		if (b[M - 1][j] == WHITE)
		{
			Q[ls].row = M - 1;
			Q[ls].col = j;
			ls = (ls + 1) % QMAX;
			depth[M - 1][j] = 1;
		}
	}

	for (i = 1; i < M - 1; i++)
	{
		if (b[i][0] == WHITE)
		{
			Q[ls].row = i;
			Q[ls].col = 0;
			ls = (ls + 1) % QMAX;
			depth[i][0] = 1;
		}

		if (b[i][N - 1] == WHITE)
		{
			Q[ls].row = i;
			Q[ls].col = N - 1;
			ls = (ls + 1) % QMAX;
			depth[i][N - 1] = 1;
		}
	}

	if (ls == 0)
	{
		// the exterior contour is all black
		Q[0].row = Q[0].col = 0;
		ls = (ls + 1) % QMAX;
		depth[0][0] = 2;
	}

	// compute the depths
	while (li != ls)
	{
		i = Q[li].row;
		j = Q[li].col;
		li = (li + 1) % QMAX;

		if (b[i][j] == WHITE)
		{
			for (k = 0; k < WMOVES; k++)
			{
				ii = i + dwrow[k];
				jj = j + dwcol[k];

				if (ii >= 0 && ii < M && jj >= 0 && jj < N && !depth[ii][jj])
				{
					if (b[ii][jj] == WHITE)
					{
						depth[ii][jj] = depth[i][j];
						li = (li - 1 + QMAX) % QMAX;
						Q[li].row = ii;
						Q[li].col = jj;
					}
					else // b[ii][jj] == BLACK
					{
						depth[ii][jj] = depth[i][j] + 1;
						Q[ls].row = ii; Q[ls].col = jj;
						ls = (ls + 1) % QMAX;
					}
				}
			}
		}
		else // b[i][j] == BLACK
		{
			for (k = 0; k < BMOVES; k++)
			{
				ii = i + dbrow[k];
				jj = j + dbcol[k];

				if (ii >= 0 && ii < M && jj >= 0 && jj < N && !depth[ii][jj])
				{
					if (b[ii][jj] == BLACK)
					{
						depth[ii][jj] = depth[i][j];
						li = (li - 1 + QMAX) % QMAX;
						Q[li].row = ii;
						Q[li].col = jj;
					}
					else // b[ii][jj] == WHITE
					{
						depth[ii][jj] = depth[i][j] + 1;
						Q[ls].row = ii; Q[ls].col = jj;
						ls = (ls + 1) % QMAX;
					}
				}
			}
		}
	}
}

void compute_components()
{
	int r, c, compact, d, sz;

	ntotal = ncomp = maxsz = maxszcomp = maxd = 0;

	for (r = 0; r < M; r++)
		for (c = 0; c < N; c++)
			if (b[r][c] == BLACK && depth[r][c] > 0)
			{
				ntotal++;
				d = depth[r][c];

				if (d / 2 > maxd)
					maxd = d / 2;

				depth[r][c] = -1;
				compact = 1;

				li = ls = 0;
				Q[0].row = r;
				Q[0].col = c;
				ls = 1 % QMAX;

				sz = 0;
				while (li != ls)
				{
					i = Q[li].row;
					j = Q[li].col;
					li = (li + 1) % QMAX;
					sz++;

					for (k = 0; k < BMOVES; k++)
					{
						ii = i + dbrow[k];
						jj = j + dbcol[k];

						if (ii >= 0 && ii < M && jj >= 0 && jj < N && depth[ii][jj] > 0)
						{
							if (b[ii][jj] == BLACK)
							{
								depth[ii][jj] = -1;
								Q[ls].row = ii;
								Q[ls].col = jj;
								ls = (ls + 1) % QMAX;
							}
							else // b[ii][jj] == WHITE
							if (depth[ii][jj] > d)
								compact = 0;
						}
					}
				}

				if (sz > maxsz)
					maxsz = sz;

				if (compact && sz > maxszcomp)
					maxszcomp = sz;

				ncomp += compact;
			}
}

int main()
{
	freopen("bmap.in", "r", stdin);
	freopen("bmap.out", "w", stdout);
	
	fgets(line, 2 * NMAX - 1, stdin);
	sscanf(line, "%d %d", &M, &N);

	for (i = 0; i < M; i++)
		fgets(b[i], NMAX - 1, stdin);

	compute_depths();
	compute_components();

	printf("%d %d\n%d %d\n%d", ntotal, maxsz, ncomp, maxszcomp, maxd);
	fprintf(stderr, "%d %d\n%d %d\n%d\n", ntotal, maxsz, ncomp, maxszcomp, maxd);

	return 0;
}
